


; GPS-PROJEKT	MAI 2006													
; Bernhard.Erfurt@gmx.de													

; KURZBESCHREIBUNG:															
; Die gesendeten Daten einer GPS-MOUSE werden eingelesen (ca. 400Byte) und	
; die erforderlichen DATEN (Koordinaten, Hhe, Kurs, Geschwindigkeit)		
; herausgefiltert,															
; Anschlieend erfolgt eine Berechnung der aktuellen Position zu der 		
; vorher einprogrammierten Ziel-Position.									
;																			
; Das Display zeigt im Grundmenue folgende Daten an: 						
; - die Entfernung zum Ziel (m/km)											
; - die Hhe (absolut/Differenz)											
; - KURS																	
; - Geschwindigkeit 														
; - Anzahl der empfangenen Satelliten										
; - Betriebsspannung														
;																			

; Anmerkung																	
; Die Berechnung der Entfernung zum Ziel ist in dieser Version 				
; auf den RAUM Deutschland (51 GRAD-Nrdliche Breite) angepasst worden		
; Bei Bedarf kann der "FAKTOR_X" entsprechend angepasst werden				

; DATEIEN:									
; "GPS_ALLGEMEIN.asm" 						
; "GPS_LCD.asm" 							
; "GPS_FUNKTIONEN.asm" 						
; "GPS_INTERRUPT.asm" 						
;											


;											
; PINBELEGUNG ATmega8						
; 											
; PB0 ==>	LCD D0							
; PB1 ==>	LCD D1							
; PB2 ==>	LCD D3							
; PB3 ==>	LCD D4							
; PB4 ==>	LCD RS							
; PB5 ==>	LCD Enable						
; PB6 ==>	Quarz							
; PB7 ==>	Quarz							
;											
; PC0 ==>	Betriebsspannung				
; PC1 ==>	Temperatur						
; PC2 ==>									
; PC3 ==>	LCD-BELEUCHTUNG	 (LOW =ON)		
; PC4 ==>									
; PC5 ==>									
; 											
; PD0 ==>	RXD								
; PD1 ==>									
; PD2 ==>	TASTER-1		 (ENTER)		
; PD3 ==>	TASTER-2		 (+)			
; PD4 ==>	TASTER-3		 (-)			
; PD5 ==>	TASTER-4		 (Escape)		
; PD6 ==>	LED-GRN		 (LOW =ON)		
; PD7 ==>	LED-BLAU		 (LOW =ON)		



; ATmega8							
.include "m8def.inc"
; CPU								
.equ TAKT					= 16000000
; ADC								
.equ SPANNUNG_REFERENZ		= 2592				; Referenzspannung an PIN AREF (2592mV am 08.05.06)		
.equ R_1					= 100				; SPANNUNGSTEILER Widerstand R1 						
.equ R_2					= 47				; SPANNUNGSTEILER Widerstand R2							
; GPS								
.equ FAKTOR_KNOTEN			= 1852				; 1 kn = 1,852 km/h 
.equ FAKTOR_X				=  70				; Faktor fr Differenz stliche LNGE 	
.equ FAKTOR_Y				= 111				; Faktor fr Different Nrdliche Breite	
; TIMER								
.equ TIMERWERT				= 65536-6250		;(2 hoch 16 minus....) ==> 0,1s			
.equ EEPROM_AUTO_SPEICHERN	= 2					; Zeit in Minuten zum speichern der Betriebsstunden (1...59)		
; USART								
.equ BRR					= TAKT/(4800*16)-1	; 4800 BAUD	
; LEDS 								
.equ LED_C_LCD				= 3
.equ LED_D_ROT				= 6
.equ LED_D_BLAU				= 7
; TASTEN							
.equ TASTE_NULL				= 0
.equ TASTE_ESC				= 1
.equ TASTE_MINUS			= 2
.equ TASTE_PLUS				= 3
.equ TASTE_ENTER			= 4
; LCD								
.equ LCD_PORT				= PORTB
.equ LCD_D0					= 0
.equ LCD_D1					= 1
.equ LCD_D2					= 2
.equ LCD_D3					= 3
.equ LCD_RS					= 4
.equ LCD_E					= 5
; EEPROM BELEGUNG					
.equ adr_EEPROM_ANZ_PROGRAMMSTARTS_L=0			; ANZAHL PROGRAMMSTARTS L	
.equ adr_EEPROM_ANZ_PROGRAMMSTARTS_H=1			; ANZAHL PROGRAMMSTARTS H	
.equ adr_EEPROM_REFERENZ_NUMMER		=2			; letzte Geladene REFERENZ	
.equ adr_EEPROM_HOEHE_OFFSET_L	    =3			; OFFSET HHE L				
.equ adr_EEPROM_HOEHE_OFFSET_H		=4			; OFFSET HHE H				
.equ adr_EEPROM_LED_LCD_ON			=5			; LED-LCD					
.equ adr_EEPROM_LED_ROT_ON			=6			; LED-ROT					
.equ adr_EEPROM_LED_BLAU_ON			=7			; LED-BLAU					
.equ adr_EEPROM_LED_ROT_INVERTIEREN	=8			; LED-ROT 0=ROT an bei V 1=ROT an bei A 
.equ adr_EEPROM_BETRIEBSSTUNDEN_hh	=9			; Betriebsstunden	
.equ adr_EEPROM_BETRIEBSSTUNDEN_mm	=10			; Betriebsstunden	
.equ adr_EEPROM_BETRIEBSSTUNDEN_ss	=11			; Betriebsstunden	

.equ adr_EEPROM_REF_A_X_LAENGE_BYTE1= 101		; REFERENZ A (LNGE)	
.equ adr_EEPROM_REF_A_X_LAENGE_BYTE2= 102
.equ adr_EEPROM_REF_A_X_LAENGE_BYTE3= 103
.equ adr_EEPROM_REF_A_X_LAENGE_BYTE4= 104
.equ adr_EEPROM_REF_A_Y_BREITE_BYTE1= 105		; REFERENZ A (BREITE)	
.equ adr_EEPROM_REF_A_Y_BREITE_BYTE2= 106
.equ adr_EEPROM_REF_A_Y_BREITE_BYTE3= 107
.equ adr_EEPROM_REF_A_Y_BREITE_BYTE4= 108
.equ adr_EEPROM_REF_A_HOEHE_L		= 109		; REFERENZ A HHE		
.equ adr_EEPROM_REF_A_HOEHE_H		= 110
.equ adr_EEPROM_REF_A_TAG			= 111		; REFERENZ A TAG		
.equ adr_EEPROM_REF_A_MONAT			= 112		; REFERENZ A MONAT		
.equ adr_EEPROM_REF_A_JAHR			= 113		; REFERENZ A JAHR		
.equ adr_EEPROM_REF_A_hh			= 114		; REFERENZ A STUNDE		
.equ adr_EEPROM_REF_A_mm			= 115		; REFERENZ A MINUTE		
.equ adr_EEPROM_REF_A_ss			= 116		; REFERENZ A SEKUNDE	

.equ adr_EEPROM_REF_B_X_LAENGE_BYTE1= 201		; REFERENZ B (LNGE)	
.equ adr_EEPROM_REF_B_X_LAENGE_BYTE2= 202
.equ adr_EEPROM_REF_B_X_LAENGE_BYTE3= 203
.equ adr_EEPROM_REF_B_X_LAENGE_BYTE4= 204
.equ adr_EEPROM_REF_B_Y_BREITE_BYTE1= 205		; REFERENZ B (BREITE)	
.equ adr_EEPROM_REF_B_Y_BREITE_BYTE2= 206
.equ adr_EEPROM_REF_B_Y_BREITE_BYTE3= 207
.equ adr_EEPROM_REF_B_Y_BREITE_BYTE4= 208
.equ adr_EEPROM_REF_B_HOEHE_L		= 209		; REFERENZ B HHE		
.equ adr_EEPROM_REF_B_HOEHE_H		= 210
.equ adr_EEPROM_REF_B_TAG			= 211		; REFERENZ B TAG		
.equ adr_EEPROM_REF_B_MONAT			= 212		; REFERENZ B MONAT		
.equ adr_EEPROM_REF_B_JAHR			= 213		; REFERENZ B JAHR		
.equ adr_EEPROM_REF_B_hh			= 214		; REFERENZ B STUNDE		
.equ adr_EEPROM_REF_B_mm			= 215		; REFERENZ B MINUTE		
.equ adr_EEPROM_REF_B_ss			= 216		; REFERENZ B SEKUNDE	

.equ adr_EEPROM_REF_C_X_LAENGE_BYTE1= 301		; REFERENZ C (LNGE)	
.equ adr_EEPROM_REF_C_X_LAENGE_BYTE2= 302
.equ adr_EEPROM_REF_C_X_LAENGE_BYTE3= 303
.equ adr_EEPROM_REF_C_X_LAENGE_BYTE4= 304
.equ adr_EEPROM_REF_C_Y_BREITE_BYTE1= 305		; REFERENZ C (BREITE)	
.equ adr_EEPROM_REF_C_Y_BREITE_BYTE2= 306
.equ adr_EEPROM_REF_C_Y_BREITE_BYTE3= 307
.equ adr_EEPROM_REF_C_Y_BREITE_BYTE4= 308
.equ adr_EEPROM_REF_C_HOEHE_L		= 309		; REFERENZ C HHE		
.equ adr_EEPROM_REF_C_HOEHE_H		= 310
.equ adr_EEPROM_REF_C_TAG			= 311		; REFERENZ C TAG		
.equ adr_EEPROM_REF_C_MONAT			= 312		; REFERENZ C MONAT		
.equ adr_EEPROM_REF_C_JAHR			= 313		; REFERENZ C JAHR		
.equ adr_EEPROM_REF_C_hh			= 314		; REFERENZ C STUNDE		
.equ adr_EEPROM_REF_C_mm			= 315		; REFERENZ C MINUTE		
.equ adr_EEPROM_REF_C_ss			= 316		; REFERENZ C SEKUNDE	

; SRAM-Belegung																			
.equ adr_DATEN						= 0x0060+0	; START Adresse aufbereiteter Daten		
.equ adr_SYSTEM_ss10				= 0x0060+0	; 10-tel Sekunde						
.equ adr_BETRIEBSSTUNDEN_ss			= 0x0060+1	; Betriebsstunden	
.equ adr_BETRIEBSSTUNDEN_mm			= 0x0060+2	; Betriebsstunden	
.equ adr_BETRIEBSSTUNDEN_hh			= 0x0060+3	; Betriebsstunden	
.equ adr_BETRIEBSSTUNDEN_SPEICHERN	= 0x0060+4	; 1=Betriebsstunden speichern		

.equ adr_ANZ_PROGRAMMSTARTS_L=0x0060+8			; ANZAHL PROGRAMMSTARTS L	
.equ adr_ANZ_PROGRAMMSTARTS_H=0x0060+9			; ANZAHL PROGRAMMSTARTS H	

.equ adr_ADC_BYTE_1 		= 0x0060+10			; BYTE1 fr ADC MITTELWERTBILDUNG	
.equ adr_ADC_BYTE_2 	 	= 0x0060+11			; BYTE2 fr ADC MITTELWERTBILDUNG	
.equ adr_ADC_BYTE_3 		= 0x0060+12			; BYTE3 fr ADC MITTELWERTBILDUNG	
.equ adr_TEMPERATUR_L		= 0x0060+13			; Temperatur						
.equ adr_TEMPERATUR_H		= 0x0060+14
.equ adr_SPANNUNG_L			= 0x0060+15			; SPANNUNG							
.equ adr_SPANNUNG_H			= 0x0060+16
.equ adr_LED_ROT_INVERTIEREN= 0x0060+17			; 0=ROT an bei V  1=ROT an bei A   	
.equ adr_FEHLER_CODE		= 0x0060+18			; FEHLER-CODE						

.equ adr_GPS_ONLINE_hh			= 0x0060+20		; ZEIT-GPS-ONLINE					
.equ adr_GPS_ONLINE_mm			= 0x0060+21
.equ adr_GPS_ONLINE_ss			= 0x0060+22

.equ adr_GPS_OFFLINE_hh			= 0x0060+23		; ZEIT-GPS-OFFLINE					
.equ adr_GPS_OFFLINE_mm			= 0x0060+24
.equ adr_GPS_OFFLINE_ss			= 0x0060+25

.equ adr_GPS_TAG				= 0x0060+30		; UTC		
.equ adr_GPS_MONAT				= 0x0060+31
.equ adr_GPS_JAHR				= 0x0060+32
.equ adr_GPS_hh					= 0x0060+33		; UTC		
.equ adr_GPS_mm					= 0x0060+34
.equ adr_GPS_ss					= 0x0060+35

.equ adr_GPS_HOEHE_L			= 0x0060+40		; GPS HHE	
.equ adr_GPS_HOEHE_H			= 0x0060+41
.equ adr_GPS_HOEHE_OFFSET_L		= 0x0060+42		; HHE-OFFSET
.equ adr_GPS_HOEHE_OFFSET_H		= 0x0060+43
.equ adr_GPS_HOEHE_BERECHNET_L	= 0x0060+44		; HHE-ERGEBNIS
.equ adr_GPS_HOEHE_BERECHNET_H	= 0x0060+45


.equ adr_GPS_GESCHWINDIGKEIT_L	= 0x0060+50		; GPS SOG		
.equ adr_GPS_GESCHWINDIGKEIT_H	= 0x0060+51
.equ adr_GPS_KURS_L				= 0x0060+52		; GPS KURS		
.equ adr_GPS_KURS_H				= 0x0060+53
.equ adr_GPS_ANZ_SAT_GESAMT		= 0x0060+54		; GPS SATELLITEN
.equ adr_GPS_ANZ_SAT_EMPFANGEN	= 0x0060+55		; GPS SATELLITEN
.equ adr_GPS_GENAUIGKEIT		= 0x0060+56
.equ adr_GPS_AKTIV				= 0x0060+57		; GPS  0=V 1=A (AKTIV)

.equ adr_GPS_ENTFERNUNG_BYTE_1	= 0x0060+60		; BERECHNETE ENTFERNUNG zum ZIEL
.equ adr_GPS_ENTFERNUNG_BYTE_2	= 0x0060+61
.equ adr_GPS_ENTFERNUNG_BYTE_3	= 0x0060+62
.equ adr_GPS_ENTFERNUNG_BYTE_4	= 0x0060+63

.equ adr_GPS_ENTFERNUNG_in_km	= 0x0060+64		; MASSEINHEIT 0=m 1=km

.equ adr_GPS_X_LAENGE_BYTE1		= 0x0060+70		; GPS POSITION-BREITE (dezimal)
.equ adr_GPS_X_LAENGE_BYTE2		= 0x0060+71
.equ adr_GPS_X_LAENGE_BYTE3		= 0x0060+72
.equ adr_GPS_X_LAENGE_BYTE4		= 0x0060+73

.equ adr_GPS_Y_BREITE_BYTE1		= 0x0060+74		; GPS POSITION-LNGE (dezimal)
.equ adr_GPS_Y_BREITE_BYTE2		= 0x0060+75
.equ adr_GPS_Y_BREITE_BYTE3		= 0x0060+76
.equ adr_GPS_Y_BREITE_BYTE4		= 0x0060+77

.equ adr_GPS_REFERENZ_X_LAENGE_BYTE1= 0x0060+78		; aktuelle REFERENZPOSITION	LNGE 
.equ adr_GPS_REFERENZ_X_LAENGE_BYTE2= 0x0060+79
.equ adr_GPS_REFERENZ_X_LAENGE_BYTE3= 0x0060+80
.equ adr_GPS_REFERENZ_X_LAENGE_BYTE4= 0x0060+81

.equ adr_GPS_REFERENZ_Y_BREITE_BYTE1= 0x0060+82		; aktuelle REFERENZPOSITION	BREITE
.equ adr_GPS_REFERENZ_Y_BREITE_BYTE2= 0x0060+83
.equ adr_GPS_REFERENZ_Y_BREITE_BYTE3= 0x0060+84
.equ adr_GPS_REFERENZ_Y_BREITE_BYTE4= 0x0060+85

.equ adr_GPS_REFERENZ_HOEHE_L		= 0x0060+86		; aktuelle REFERENZ HHE			
.equ adr_GPS_REFERENZ_HOEHE_H		= 0x0060+87

.equ adr_X_LAENGE_DIFFERENZ_BYTE1	= 0x0060+102	; Zwischenergebnis	
.equ adr_X_LAENGE_DIFFERENZ_BYTE2	= 0x0060+103
.equ adr_X_LAENGE_DIFFERENZ_BYTE3	= 0x0060+104
.equ adr_X_LAENGE_DIFFERENZ_BYTE4	= 0x0060+105

.equ adr_Y_BREITE_DIFFERENZ_BYTE1	= 0x0060+106	; Zwischenergebnis	
.equ adr_Y_BREITE_DIFFERENZ_BYTE2	= 0x0060+107
.equ adr_Y_BREITE_DIFFERENZ_BYTE3	= 0x0060+108
.equ adr_Y_BREITE_DIFFERENZ_BYTE4	= 0x0060+109

.equ adr_AKTIVIERUNG_ANZEIGE			= 0x0060+200	; ANZEIGE REFRESH	
.equ adr_AKTIVIERUNG_GPS_EMPFANG		= 0x0060+201	; DATEN einlesen	
.equ adr_AKTIVIERUNG_GPS_AUFBEREITUNG	= 0x0060+202	; DATEN berechnen	

.equ adr_GPS_DATEN_SCHREIB_POSITION_L	= 0x0060+210	; DATEN im SRAM		
.equ adr_GPS_DATEN_SCHREIB_POSITION_H	= 0x0060+211

.equ adr_GPS_DATEN_ZEICHEN_ANZAHL_L		= 0x0060+220	; DATEN im SRAM		
.equ adr_GPS_DATEN_ZEICHEN_ANZAHL_H		= 0x0060+221

.equ adr_GPS_DATEN_DATENSATZ_ANZAHL		= 0x0060+230	; 6 DATENSTZE ($GPGGA,$GPGSA,$GPGSV-1,$GPGSV-2,$GPGSV-3,$GPRMC

.equ adr_GPS_DATEN_BEREICH_BEGINN		= 0x0060+250	; GPS-DATEN-STRING
.equ adr_GPS_DATEN_BEREICH_ENDE 		= RAMEND-250	; GPS-DATEN-STRING


; REGISTER					
.def TASTE				=R2
.def MENUE_0			=R3
.def MENUE_1			=R4

.def REFERENZ_NUMMER	=R5			; A(EEPROM),B(EEPROM),C(EEPROM),1,2,3,4,5,6,7,8,9,10...

.def GPS_EMPFANGSZEICHEN=R9

.def temp  = r16
.def temp1 = r17
.def temp2 = r18
.def temp3 = r19
.def temp4 = r20
.def temp5 = r21
.def temp6 = r22
.def temp7 = r23
.def temp8 = r24
.def temp9 = r25

.def XL		=R26
.def XH		=R27
.def YL		=R28
.def YH		=R29
.def ZL		=R30		; ZEIGER fr TEXTE
.def ZH		=R31

.cseg					;Beginn eines Code-Segmentes
.org 0					;Startadresse=0

rjmp RESET      ; Reset Handler                           
reti ;rjmp EXT_INT0   ; IRQ0 Handler                      
reti ;rjmp EXT_INT1   ; IRQ1 Handler                      
reti ;rjmp TIM2_COMP  ; Timer2 Compare Handler            
reti ;rjmp TIM2_OVF   ; Timer2 Overflow Handler           
reti ;rjmp TIM1_CAPT  ; Timer1 Capture Handler            
reti ;rjmp TIM1_COMPA ; Timer1 CompareA Handler           
reti ;rjmp TIM1_COMPB ; Timer1 CompareB Handler           
rjmp TIM1_OVF   ; Timer1 Overflow Handler           	  
reti ;rjmp TIM0_OVF   ; Timer0 Overflow Handler           
reti ;rjmp SPI_STC    ; SPI Transfer Complete Handler     
rjmp ZEICHEN_EINLESEN ; USART RX Complete Handler     	  
reti ;rjmp USART_UDRE ; UDR Empty Handler                 
reti ;rjmp USART_TXC  ; USART TX Complete Handler         
reti ;rjmp ADC        ; ADC Conversion Complete Handler   
reti ;rjmp EE_RDY     ; EEPROM Ready Handler              
reti ;rjmp ANA_COMP   ; Analog Comparator Handler         
reti ;rjmp TWSI       ; Two-wire Serial Interface Handler 
reti ;rjmp SPM_RDY    ; Store Program Memory Ready Handler


RESET:                        
; STACK initialisieren
	ldi temp, LOW(RAMEND)      ; LOW-Byte der obersten RAM-Adresse
	out SPL, temp
	ldi temp, HIGH(RAMEND)     ; HIGH-Byte der obersten RAM-Adresse
	out SPH, temp
; PORT B initialisieren	
	ldi temp, 0b00111111    ; QUARZ / LCD 		
	out DDRB, temp
; PORT B setzen			
	out PORTB, temp

; PORT C initialisieren	
	ldi temp, 0b00001000    ; LED /Messeingnge
	out DDRC, temp
; PORT C setzen			
	out PORTC, temp

; PORT D  initialisieren	
	ldi temp, 0b11000010	; RXD/TXD/4xTASTER/2xLED
	out DDRD, temp
; PORT D setzen			
	ldi temp, 0b11111111	; PULL-UPS aktivieren 	
	out PORTD, temp
; LED / LCD an			
	cbi PORTD, LED_D_ROT	; ROT an	
	cbi PORTD, LED_D_BLAU	; BLAU an	
	cbi PORTC, LED_C_LCD	; LCD  an	

;USART initialisieren		
	ldi temp, low(BRR)  		; Baudrate 					
	out UBRRL,temp
	ldi temp,high(BRR)  		; Baudrate 					
	out UBRRH,temp
   	ldi temp, (1<<URSEL)|(3<<UCSZ0)	; Frame-Format: 8 Bit		
    out UCSRC, temp
    sbi UCSRB, RXCIE                ; Interrupt bei Empfang     
    sbi UCSRB, RXEN 				; RX (Empfang) aktivieren   
	sbi UCSRB, TXEN  				; TX aktivieren             
; Watchdog aktivieren (max. Zeit)
	ldi TEMP,(1<<WDCE)|(1<<WDE)  
	out wdtcr,TEMP       
	ldi TEMP,(1<<WDE) | (1<<WDP2)|(1<<WDP1)|(1<<WDP0) 
	out wdtcr,temp
; PAUSE					
	rcall wait_100ms
; LCD initialisieren	
	rcall lcd_init	
; LCD BEGRUESSUNG		
	rcall ANZEIGE_BEGRUESSUNG
	rcall WAIT_1s
; LCD_SONDERZEICHEN_PROGRAMMIEREN_0	
	rcall LCD_SONDERZEICHEN_PROGRAMMIEREN_0		; ; ""								
; LCD_SONDERZEICHEN_PROGRAMMIEREN_4	
	rcall LCD_SONDERZEICHEN_PROGRAMMIEREN_4		; /h				

; Timer1-Vorteiler 					  
; TCCR1B ==> ICNC1 ICES1 R WGM13 WGM12 CS12 CS11 CS10 
; 000 TIMER aus                 
; 001 CLOCK=TAKTFREQUENZ / 1    
; 010 CLOCK=TAKTFREQUENZ / 8    
; 011 CLOCK=TAKTFREQUENZ / 64   
; 100 CLOCK=TAKTFREQUENZ / 256  
; 101 CLOCK=TAKTFREQUENZ / 1024 
; 110 Abfallende Flanke Pin T0  
; 111 Steigende  Flanke Pin T0  
	ldi temp, 1<<CS12|0<<CS11|0<<CS10  ; 256	
	out TCCR1B,temp          
;Timer1-berlauf-Int aktivieren       
 	ldi temp,(1<<toie1)
 	out timsk,temp          
; Timer Startwert 						
	ldi temp,HIGH(TIMERWERT)	;HIGH
	out tcnt1H,temp         
	ldi temp,LOW(TIMERWERT)   	;LOW   
	out tcnt1L,temp     

; ADC initialisieren mit "Free Run" und Vorteiler 128 	
; Bit 7 -ADEN: ADC Enable                             	
; Bit 6 -ADSC: ADC Start Conversion                   	
; Bit 5 -ADFR: ADC Free Running Select                	
; Bit 4 -ADIF: ADC Interrzpt Flag                     	
; Bit 3 -ADIE: ADC Interrupt Enable                   	
; Bit 2 -ADPS2: Vorteiler                             	
; Bit 1 -ADPS2: Vorteiler                             	
; Bit 0 -ADPS2: Vorteiler                             	
;	ADPS2 ADPS1 ADPS0 Division Factor					
;	0 		0 	0 		2								
;	0 		0 	1 		2								
;	0 		1 	0 		4								
;	0 		1 	1 		8								
;	1 		0 	0 		16								
;	1 		0 	1	 	32								
;	1 		1 	0 		64								
;	1 		1 	1 		128								
;														
	ldi temp, ((1<<ADEN)|(1<<ADSC)|(1<<ADFR)|(1<<ADPS2)|(1<<ADPS1)|(0<<ADPS0)) ; VT: 64
	out ADCSR, temp
; ADC initialisieren  ###########################################
; REFS1 REFS0 Voltage Reference Selection											
;  0     0    AREF, Internal Vref turned off										
;  0     1    AVCC with external capacitor at AREF pin								
;  1     1    Internal 2.56V Voltage Reference with external capacitor at AREF pin	
	ldi temp, 1<<REFS1 | 1<<REFS0
	out ADMUX, temp

; SRAM lschen								
SRAM_CLEAR:
	ldi ZL, LOW (adr_DATEN)
	ldi ZH, HIGH(adr_DATEN)
	clr temp
SRAM_CLEAR_w:
	ST z+,temp
	cpi ZH, HIGH(RAMEND); Vergleich?		
	brlo SRAM_CLEAR_w	; kleiner => SPRUNG	
	cpi ZL, LOW(RAMEND)	; Vergleich?		
	brlo SRAM_CLEAR_w	; kleiner => SPRUNG	
	breq SRAM_CLEAR_w	; gleich  => SPRUNG	


;											
; STARTWERTE								
;											


; REGISTER clear							
 	clr TASTE
	clr MENUE_0
	clr MENUE_1
; EXTRF + PORF FLAG zurcksetzen			
	in temp, MCUCSR
	andi temp, 0b11111100
	out MCUCSR,temp
; LEDs off									
	sbi PORTD, LED_D_BLAU	; BLAU aus	
	sbi PORTD, LED_D_ROT	; ROT  aus	

; SYSTEM_EINSTELLUNGEN_EEPROM_LADEN			
	rcall SYSTEM_EINSTELLUNGEN_EEPROM_LADEN
; PROGRAMMSTARTS_ZHLEN						
	rcall PROGRAMMSTARTS_ZAEHLEN
; REFERENZ laden							
	rcall GPS_REFERENZ_LADEN	
; ANZEIGE_ANZAHL_PROGRAMM_STARTS			
	rcall ANZEIGE_ANZAHL_PROGRAMM_STARTS
	rcall WAIT_1s
; ANZEIGE_MCUCSR							
	rcall ANZEIGE_MCUCSR
	rcall WAIT_1s
; GPS_DATENEMPFANG aktivieren				
	rcall GPS_CLEAR_START		

;Interrupts allgemein aktivieren			
sei                   



;######################################################################## 
;######################################################################## 
;######################################################################## 
loop:
	wdr									; WATCH-DOG-RESET	
	rcall ANZEIGE_LED_ROT				; GPS A/V			
	rcall BETRIEBSSTUNDEN_SPEICHERN		; BETRIEBSSTUNDEN 	
	rcall BERECHNUNG_ONLINE_OFFLINE		; ZEITEN ONLINE/OFFLINE

	; ANZEIGE 
	LDS temp,(adr_AKTIVIERUNG_ANZEIGE)	; aus SRAM laden	
	tst temp	
	brne LOOP_w
	rjmp LOOP
LOOP_W:
	clr temp
	STS (adr_AKTIVIERUNG_ANZEIGE),temp	; in SRAM speichern	

	rcall MESSEN_0						; Betriebsspannung	
	rcall MESSEN_1						; Temperatur		

	rcall ABFRAGE_TASTATUR				; TASTATUR			

	rcall STEUERUNG_MENUE_EBENE_0				; MENUE
	rcall STEUERUNG_MENUE_POSITIONEN_LADEN		; MENUE
	rcall STEUERUNG_MENUE_POSITIONEN_SPEICHERN	; MENUE
	rcall STEUERUNG_MENUE_EDIT					; MENUE

rjmp loop
;###################################################################
;###################################################################
;###################################################################
; OUT: TASTE														
ABFRAGE_TASTATUR:
	in temp, PIND			; einlesen		
	andi temp, 0b00111100	; Bitmuster		
	com temp				; invertieren	
	andi temp, 0b00111100	; Bitmuster		
	LSR temp				; 1 x rechts	
	LSR temp				; 1 x rechts	
	cpi temp,0				; = 0 ? (keine TASTE gedrckt)	
	breq ABFRAGE_TASTATUR_0
	cpi temp,1				; = 1 ? (TASTE-1) ESC			
	breq ABFRAGE_TASTATUR_4
	cpi temp,2				; = 2 ? (TASTE-2)	-			
	breq ABFRAGE_TASTATUR_3
	cpi temp,4				; = 4 ? (TASTE-3)	+			
	breq ABFRAGE_TASTATUR_2
	cpi temp,8				; = 8 ? (TASTE-4) ENTER			
	breq ABFRAGE_TASTATUR_1
	ret
ABFRAGE_TASTATUR_0:
	clr TASTE				; (TASTE-0) keine TASTE		
	ret
ABFRAGE_TASTATUR_1:
 	clr TASTE				; (TASTE-1) ESC				
	clr MENUE_0
	clr MENUE_1
	ret
ABFRAGE_TASTATUR_2: 
	ldi temp,TASTE_MINUS	; (TASTE-2)	MINUS			
	mov TASTE,temp
	ret
ABFRAGE_TASTATUR_3:
	ldi temp,TASTE_PLUS		; (TASTE-3)	PLUS			
	mov TASTE,temp
	ret
ABFRAGE_TASTATUR_4:
	ldi temp,TASTE_ENTER	; (TASTE-4) ENTER			
	mov TASTE,temp
ret
;######################################################################## 
;######################################################################## 
;######################################################################## 	
;																		  	
; rcall ABFRAGE_TASTATUR_TASTE_ENTER ;OUT: FLAGS (bei ENTER-TASTE=>TASTE=0)	
;																		  	
ABFRAGE_TASTATUR_TASTE_ENTER:
	mov temp, TASTE
	cpi temp, TASTE_ENTER
	brne ABFRAGE_TASTATUR_TASTE_ENTER_w
	; TASTE clear	
	clr TASTE
ABFRAGE_TASTATUR_TASTE_ENTER_w:
ret
;######################################################################## 
;######################################################################## 
;######################################################################## 
;																		  	
; rcall ABFRAGE_TASTATUR_TASTE_MINUS ; OUT: FLAGS							
;																		  	
ABFRAGE_TASTATUR_TASTE_MINUS:
	mov temp, TASTE
	cpi temp, TASTE_MINUS
ret
;######################################################################## 
;######################################################################## 
;######################################################################## 
;																		  	
; rcall ABFRAGE_TASTATUR_TASTE_PLUS ; OUT: FLAGS							
;																		  	
ABFRAGE_TASTATUR_TASTE_PLUS:
	mov temp, TASTE
	cpi temp, TASTE_PLUS
ret
;######################################################################## 
;######################################################################## 
;######################################################################## 
; ANZEIGE GRUND-MENUE														
STEUERUNG_MENUE_EBENE_0:
	tst MENUE_1
	breq STEUERUNG_MENUE_EBENE_0_START
	ret
STEUERUNG_MENUE_EBENE_0_START:
	; TASTATUR	
	rcall ABFRAGE_TASTATUR_TASTE_MINUS ; OUT: FLAGS
	brne STEUERUNG_MENUE_EBENE_0_TASTE
	dec MENUE_0							; -1 
STEUERUNG_MENUE_EBENE_0_TASTE:
	; TASTATUR	
	rcall ABFRAGE_TASTATUR_TASTE_PLUS ; OUT: FLAGS
	brne STEUERUNG_MENUE_EBENE_0_TASTE_w
	inc MENUE_0							; +1 
STEUERUNG_MENUE_EBENE_0_TASTE_w:
	; TASTATUR	
	rcall ABFRAGE_TASTATUR_TASTE_ENTER ;OUT: FLAGS (bei ENTER-TASTE=>TASTE=0)	
	brne STEUERUNG_MENUE_EBENE_0_0
	inc MENUE_1							; +1 
	ret
;-----------------------------------------------------------------------------
STEUERUNG_MENUE_EBENE_0_0:
	mov temp, MENUE_0
	cpi temp,0							; vergleich				
	brne STEUERUNG_MENUE_EBENE_0_1		; ist ungleich => SPRUNG
	rcall ANZEIGE_HAUPTMENUE							; ANZEIGE HAUPTMENUE	
	ret
STEUERUNG_MENUE_EBENE_0_1:
	cpi temp,1							; vergleich				
	brne STEUERUNG_MENUE_EBENE_0_2		; ist ungleich => SPRUNG
	rcall ANZEIGE_REFERENZ_GELADEN_INFO_NAME			; geladene REFERENZ Name		
	ret
STEUERUNG_MENUE_EBENE_0_2:
	cpi temp,2							; vergleich				
	brne STEUERUNG_MENUE_EBENE_0_3		; ist ungleich => SPRUNG
	rcall ANZEIGE_UTC_ZEIT								; ANZEIGE_UTC_ZEIT
	ret
STEUERUNG_MENUE_EBENE_0_3:
	cpi temp,3							; vergleich				
	brne STEUERUNG_MENUE_EBENE_0_4		; ist ungleich => SPRUNG
	rcall ANZEIGE_SPANNUNG_TEMPERATUR					; ANZEIGE_SPANNUNG_TEMPERATUR
	ret
STEUERUNG_MENUE_EBENE_0_4:
	cpi temp,4							; vergleich				
	brne STEUERUNG_MENUE_EBENE_0_5		; ist ungleich => SPRUNG
	rcall ANZEIGE_SATELLITEN							; ANZAHL der SATELLITEN			
	ret
STEUERUNG_MENUE_EBENE_0_5:
	cpi temp,5							; vergleich				
	brne STEUERUNG_MENUE_EBENE_0_6		; ist ungleich => SPRUNG
	rcall ANZEIGE_X_Y_DIFFERENZ							; ANZEIGE_X_Y_DIFFERENZ
	ret
;---------------------------------------------------------------------------------------------------------------------
STEUERUNG_MENUE_EBENE_0_6:
	cpi temp,6							; vergleich				
	brne STEUERUNG_MENUE_EBENE_0_7		; ist ungleich => SPRUNG
	rcall ANZEIGE_REFERENZ_POSITIONEN_LADEN				; HAUPTMENUE - POSITIONEN LADEN		
	ret
STEUERUNG_MENUE_EBENE_0_7:
	cpi temp,7							; vergleich				
	brne STEUERUNG_MENUE_EBENE_0_8		; ist ungleich => SPRUNG
	rcall ANZEIGE_REFERENZ_POSITIONEN_SPEICHERN			; HAUPTMENUE - POSITIONEN SPEICHERN	
	ret
STEUERUNG_MENUE_EBENE_0_8:
	cpi temp,8							; vergleich				
	brne STEUERUNG_MENUE_EBENE_0_9		; ist ungleich => SPRUNG
	rcall ANZEIGE_TEXT_EDIT								; HAUPTMENUE - EDIT					
	ret
;-----------------------------------------------------------------------------------------------------------------------
STEUERUNG_MENUE_EBENE_0_9:
	cpi temp,9							; vergleich				
	brne STEUERUNG_MENUE_EBENE_0_10		; ist ungleich => SPRUNG
	rcall ANZEIGE_ONLINE_OFFLINE						; ANZEIGE_ONLINE_OFFLINE
	ret

STEUERUNG_MENUE_EBENE_0_10:
	cpi temp,10							; vergleich				
	brne STEUERUNG_MENUE_EBENE_0_11		; ist ungleich => SPRUNG
	rcall ANZEIGE_GPS_POSITION_AKTUELL_DEZIMAL			; POSITION DEZIMAL					
	ret
STEUERUNG_MENUE_EBENE_0_11:
	cpi temp,11							; vergleich				
	brne STEUERUNG_MENUE_EBENE_0_12		; ist ungleich => SPRUNG
	rcall ANZEIGE_GPS_POSITION_AKTUELL_GRD_MIN_SEKUNDE	; POSITION GRD SEK				
	ret
STEUERUNG_MENUE_EBENE_0_12:
	cpi temp,12							; vergleich				
	brne STEUERUNG_MENUE_EBENE_0_13		; ist ungleich => SPRUNG
	rcall ANZEIGE_REFERENZ_GELADEN_INFO_KOORDINATEN		; geladene REFERENZ KOORDINATEN		
	ret
STEUERUNG_MENUE_EBENE_0_13:
	cpi temp,13							; vergleich				
	brne STEUERUNG_MENUE_EBENE_0_14		; ist ungleich => SPRUNG
	rcall ANZEIGE_ANZAHL_PROGRAMM_STARTS				; ANZAHL PROGRAMM -STARTS
	ret
STEUERUNG_MENUE_EBENE_0_14:
	cpi temp,14							; vergleich				
	brne STEUERUNG_MENUE_EBENE_0_15		; ist ungleich => SPRUNG
	rcall ANZEIGE_BETRIEBSSTUNDEN						; ANZEIGE_BETRIEBSSTUNDEN
	ret
STEUERUNG_MENUE_EBENE_0_15:
	cpi temp,15							; vergleich				
	brne STEUERUNG_MENUE_EBENE_0_16		; ist ungleich => SPRUNG
	rcall ANZEIGE_HOEHE_GPS_UND_BERECHNET				; ANZEIGE_HOEHE_GPS_UND_BERECHNET
	ret
STEUERUNG_MENUE_EBENE_0_16:
	cpi temp,16							; vergleich				
	brne STEUERUNG_MENUE_EBENE_0_17		; ist ungleich => SPRUNG
	rcall ANZEIGE_LEER_MENUE							; !!!!! LEER !!!!!!
	ret
STEUERUNG_MENUE_EBENE_0_17:
	cpi temp,17							; vergleich				
	brne STEUERUNG_MENUE_EBENE_0_18		; ist ungleich => SPRUNG
	rcall ANZEIGE_LEER_MENUE							; !!!!! LEER !!!!!!
	ret
;--------------------------------------------------------------------------------
STEUERUNG_MENUE_EBENE_0_18:
	cpi temp,18							; vergleich				
	brne STEUERUNG_MENUE_EBENE_0_19		; ist ungleich => SPRUNG
	ldi XL, low(adr_GPS_DATEN_BEREICH_BEGINN+0)
	ldi XH,high(adr_GPS_DATEN_BEREICH_BEGINN+0)	
	rcall ANZEIGE_GPS_STRING							; ANZEIGE_GPS_STRING 1
	ret
STEUERUNG_MENUE_EBENE_0_19:
	cpi temp,19							; vergleich				
	brne STEUERUNG_MENUE_EBENE_0_20		; ist ungleich => SPRUNG
	ldi XL, low(adr_GPS_DATEN_BEREICH_BEGINN+32)
	ldi XH,high(adr_GPS_DATEN_BEREICH_BEGINN+32)	
	rcall ANZEIGE_GPS_STRING							; ANZEIGE_GPS_STRING 2
	ret
STEUERUNG_MENUE_EBENE_0_20:
	cpi temp,20							; vergleich				
	brne STEUERUNG_MENUE_EBENE_0_21		; ist ungleich => SPRUNG
	ldi XL, low(adr_GPS_DATEN_BEREICH_BEGINN+64)
	ldi XH,high(adr_GPS_DATEN_BEREICH_BEGINN+64)	
	rcall ANZEIGE_GPS_STRING							; ANZEIGE_GPS_STRING 3
	ret
STEUERUNG_MENUE_EBENE_0_21:
	cpi temp,21							; vergleich				
	brne STEUERUNG_MENUE_EBENE_0_22		; ist ungleich => SPRUNG
	ldi XL, low(adr_GPS_DATEN_BEREICH_BEGINN+96)
	ldi XH,high(adr_GPS_DATEN_BEREICH_BEGINN+96)	
	rcall ANZEIGE_GPS_STRING							; ANZEIGE_GPS_STRING 4
	ret
STEUERUNG_MENUE_EBENE_0_22:
	cpi temp,22							; vergleich				
	brne STEUERUNG_MENUE_EBENE_0_23		; ist ungleich => SPRUNG
	ldi XL, low(adr_GPS_DATEN_BEREICH_BEGINN+128)
	ldi XH,high(adr_GPS_DATEN_BEREICH_BEGINN+128)	
	rcall ANZEIGE_GPS_STRING							; ANZEIGE_GPS_STRING 5
	ret
STEUERUNG_MENUE_EBENE_0_23:
	cpi temp,23							; vergleich				
	brne STEUERUNG_MENUE_EBENE_0_24		; ist ungleich => SPRUNG
	ldi XL, low(adr_GPS_DATEN_BEREICH_BEGINN+160)
	ldi XH,high(adr_GPS_DATEN_BEREICH_BEGINN+160)	
	rcall ANZEIGE_GPS_STRING							; ANZEIGE_GPS_STRING 5
	ret
STEUERUNG_MENUE_EBENE_0_24:
	cpi temp,24							; vergleich				
	brne STEUERUNG_MENUE_EBENE_0_25		; ist ungleich => SPRUNG
	ldi XL, low(adr_GPS_DATEN_BEREICH_BEGINN+192)
	ldi XH,high(adr_GPS_DATEN_BEREICH_BEGINN+192)	
	rcall ANZEIGE_GPS_STRING							; ANZEIGE_GPS_STRING 5
	ret
STEUERUNG_MENUE_EBENE_0_25:
	cpi temp,25							; vergleich				
	brne STEUERUNG_MENUE_EBENE_0_26		; ist ungleich => SPRUNG
	rcall ANZEIGE_LEER_MENUE			; !!!!! LEER !!!!!!
	ret
STEUERUNG_MENUE_EBENE_0_26:
	cpi temp,26							; vergleich				
	brne STEUERUNG_MENUE_EBENE_0_27		; ist ungleich => SPRUNG
	rcall ANZEIGE_LEER_MENUE			; !!!!! LEER !!!!!!
	ret
STEUERUNG_MENUE_EBENE_0_27:
	cpi temp,27							; vergleich				
	brne STEUERUNG_MENUE_EBENE_0_28		; ist ungleich => SPRUNG
	rcall ANZEIGE_LEER_MENUE			; !!!!! LEER !!!!!!
	ret
STEUERUNG_MENUE_EBENE_0_28:
	cpi temp,28							; vergleich				
	brne STEUERUNG_MENUE_EBENE_0_29		; ist ungleich => SPRUNG
	rcall ANZEIGE_LEER_MENUE			; !!!!! LEER !!!!!!
	ret
STEUERUNG_MENUE_EBENE_0_29:
	cpi temp,29							; vergleich				
	brne STEUERUNG_MENUE_EBENE_0_30		; ist ungleich => SPRUNG
	rcall ANZEIGE_LEER_MENUE			; !!!!! LEER !!!!!!
	ret
STEUERUNG_MENUE_EBENE_0_30:
	rcall ANZEIGE_LEER_MENUE			; !!!!! LEER !!!!!!

ret
;######################################################################## 
;######################################################################## 
;######################################################################## 
; ANZEIGE MENUE-EDIT													
STEUERUNG_MENUE_EDIT:
	mov temp,MENUE_0			
	cpi temp, 8							; MENUE_0=8   ?
	breq STEUERUNG_MENUE_EDIT_START
	ret
STEUERUNG_MENUE_EDIT_START:
	tst MENUE_1							; MENUE_1<>=0 ?
	brne STEUERUNG_MENUE_EDIT_START_w
	ret
STEUERUNG_MENUE_EDIT_START_w:
; ------------------------------------------------------
	; LCD CLEAR
	rcall LCD_CLEAR
	; TASTATUR	
	rcall ABFRAGE_TASTATUR_TASTE_MINUS ; OUT: FLAGS
	brne STEUERUNG_MENUE_EDIT_w
	dec MENUE_1							; -1 
STEUERUNG_MENUE_EDIT_w:
	; TASTATUR	
	rcall ABFRAGE_TASTATUR_TASTE_PLUS ; OUT: FLAGS
	brne STEUERUNG_MENUE_EDIT_ww
	inc MENUE_1							; +1 
STEUERUNG_MENUE_EDIT_ww:
	; FEHLERPRFUNG
	tst MENUE_1							; =0 ?
	brne STEUERUNG_MENUE_EDIT_www		; nein ==SPRUNG	
	inc MENUE_1							; +1 
STEUERUNG_MENUE_EDIT_www:
	mov temp, MENUE_1
; ------------------------------------------------------
	cpi temp,1
	brne STEUERUNG_MENUE_EDIT_2
	rcall ANZEIGE_HILFE_PLUS_TASTE		; TASTE + bettigen
	ret
; ------------------------------------------------------
; HHE	TEXT_HOEHE_OFFSET_NULL
STEUERUNG_MENUE_EDIT_2:
	cpi temp,2
	brne STEUERUNG_MENUE_EDIT_3
	ldi ZH, high(TEXT_HOEHE_OFFSET_NULL*2)	; TEXT 	
	ldi ZL, low (TEXT_HOEHE_OFFSET_NULL*2)
	rcall ANZEIGE_TEXT
	rcall LCD_ZEILE2
	rcall ANZEIGE_HOEHE_BERECHNET_KURZ		; HHE	
	; TASTATUR	
	rcall ABFRAGE_TASTATUR_TASTE_ENTER ;OUT: FLAGS (bei ENTER-TASTE=>TASTE=0)	
	brne STEUERUNG_MENUE_EDIT_5w_DUMMY
	; AKTION	
	clr temp
	STS(adr_GPS_HOEHE_OFFSET_L),temp
	STS(adr_GPS_HOEHE_OFFSET_H),temp
	rcall SYSTEM_EINSTELLUNGEN_EEPROM_SPEICHERN ; SPEICHERN
	ret
; ----------------------------------------------------
; HHE	TEXT_HOEHE_OFFSET_GPS
STEUERUNG_MENUE_EDIT_3:
	cpi temp,3
	brne STEUERUNG_MENUE_EDIT_4
	ldi ZH, high(TEXT_HOEHE_OFFSET_GPS*2)	; TEXT 	
	ldi ZL, low (TEXT_HOEHE_OFFSET_GPS*2)
	rcall ANZEIGE_TEXT
	rcall LCD_ZEILE2
	rcall ANZEIGE_HOEHE_BERECHNET_KURZ		; HHE	
	; TASTATUR	
	rcall ABFRAGE_TASTATUR_TASTE_ENTER ;OUT: FLAGS (bei ENTER-TASTE=>TASTE=0)	
	brne STEUERUNG_MENUE_EDIT_5w_DUMMY
	; AKTION	
	LDS temp1,(adr_GPS_HOEHE_L)
	LDS temp2,(adr_GPS_HOEHE_H)
	STS(adr_GPS_HOEHE_OFFSET_L),temp1
	STS(adr_GPS_HOEHE_OFFSET_H),temp2
	rcall SYSTEM_EINSTELLUNGEN_EEPROM_SPEICHERN ; SPEICHERN
	ret
; ----------------------------------------------------
; HHE	TEXT_HOEHE_OFFSET_REFERENZ
STEUERUNG_MENUE_EDIT_4:
	cpi temp,4
	brne STEUERUNG_MENUE_EDIT_5
	ldi ZH, high(TEXT_HOEHE_OFFSET_REF*2)	; TEXT 	
	ldi ZL, low (TEXT_HOEHE_OFFSET_REF*2)
	rcall ANZEIGE_TEXT
	rcall LCD_ZEILE2
	rcall ANZEIGE_HOEHE_BERECHNET_KURZ		; HHE	
	; TASTATUR	
	rcall ABFRAGE_TASTATUR_TASTE_ENTER ;OUT: FLAGS (bei ENTER-TASTE=>TASTE=0)	
	brne STEUERUNG_MENUE_EDIT_5w_DUMMY
	; AKTION	
	LDS temp1,(adr_GPS_REFERENZ_HOEHE_L)
	LDS temp2,(adr_GPS_REFERENZ_HOEHE_H)
	STS(adr_GPS_HOEHE_OFFSET_L),temp1
	STS(adr_GPS_HOEHE_OFFSET_H),temp2
	rcall SYSTEM_EINSTELLUNGEN_EEPROM_SPEICHERN ; SPEICHERN
	ret
; ------------------------------------------------------
; LED ALLE OFF												
STEUERUNG_MENUE_EDIT_5:
	cpi temp,5
	brne STEUERUNG_MENUE_EDIT_6
	ldi ZH, high(TEXT_LED_OFF*2)	; TEXT 
	ldi ZL, low (TEXT_LED_OFF*2)
	rcall ANZEIGE_TEXT
	; TASTATUR	
	rcall ABFRAGE_TASTATUR_TASTE_ENTER ;OUT: FLAGS (bei ENTER-TASTE=>TASTE=0)	
	brne STEUERUNG_MENUE_EDIT_5w_DUMMY
	; AKTION	
	cbi DDRC, LED_C_LCD		; LCD-LICHT aus	
	cbi DDRD, LED_D_ROT		; ROT 		aus	
	cbi DDRD, LED_D_BLAU	; BLAU 		aus	
	rcall SYSTEM_EINSTELLUNGEN_EEPROM_SPEICHERN ; SPEICHERN
STEUERUNG_MENUE_EDIT_5w_DUMMY:
ret
; ----------------------------------------------------
; LED ALLE ON	
STEUERUNG_MENUE_EDIT_6:
	cpi temp,6
	brne STEUERUNG_MENUE_EDIT_7
	ldi ZH, high(TEXT_LED_ON*2)	; TEXT 
	ldi ZL, low (TEXT_LED_ON*2)
	rcall ANZEIGE_TEXT
	; TASTATUR	
	rcall ABFRAGE_TASTATUR_TASTE_ENTER ;OUT: FLAGS (bei ENTER-TASTE=>TASTE=0)	
	brne STEUERUNG_MENUE_EDIT_5w_DUMMY
	; AKTION	
	sbi DDRC, LED_C_LCD		; LCD-LICHT an	
	sbi DDRD, LED_D_ROT		; ROT 		an	
	sbi DDRD, LED_D_BLAU	; BLAU 		an	
	rcall SYSTEM_EINSTELLUNGEN_EEPROM_SPEICHERN ; SPEICHERN
	ret
; ----------------------------------------------------
; LCD-LICHT aus	
STEUERUNG_MENUE_EDIT_7:
	cpi temp,7
	brne STEUERUNG_MENUE_EDIT_8
	ldi ZH, high(TEXT_LED_LCD_OFF*2)	; TEXT 
	ldi ZL, low (TEXT_LED_LCD_OFF*2)
	rcall ANZEIGE_TEXT
	; TASTATUR	
	rcall ABFRAGE_TASTATUR_TASTE_ENTER ;OUT: FLAGS (bei ENTER-TASTE=>TASTE=0)	
	brne STEUERUNG_MENUE_EDIT_5w_DUMMY
	; AKTION	
	cbi DDRC, LED_C_LCD							; LCD-LICHT aus	
	rcall SYSTEM_EINSTELLUNGEN_EEPROM_SPEICHERN ; SPEICHERN
	ret
; ----------------------------------------------------
; ROT aus											
STEUERUNG_MENUE_EDIT_8:
	cpi temp,8
	brne STEUERUNG_MENUE_EDIT_9
	ldi ZH, high(TEXT_LED_ROT_OFF*2)			; TEXT 
	ldi ZL, low (TEXT_LED_ROT_OFF*2)
	rcall ANZEIGE_TEXT
	; TASTATUR	
	rcall ABFRAGE_TASTATUR_TASTE_ENTER ;OUT: FLAGS (bei ENTER-TASTE=>TASTE=0)	
	brne STEUERUNG_MENUE_EDIT_5w_DUMMY
	; AKTION	
	cbi DDRD, LED_D_ROT							; ROT 		aus	
	rcall SYSTEM_EINSTELLUNGEN_EEPROM_SPEICHERN ; SPEICHERN
	ret
; ----------------------------------------------------
; LED BLAU aus	
STEUERUNG_MENUE_EDIT_9:
	cpi temp,9
	brne STEUERUNG_MENUE_EDIT_10
	ldi ZH, high(TEXT_LED_BLAU_OFF*2)			; TEXT 
	ldi ZL, low (TEXT_LED_BLAU_OFF*2)
	rcall ANZEIGE_TEXT
	; TASTATUR	
	rcall ABFRAGE_TASTATUR_TASTE_ENTER ;OUT: FLAGS (bei ENTER-TASTE=>TASTE=0)	
	brne STEUERUNG_MENUE_EDIT_DUMMY
	; AKTION	
	cbi DDRD, LED_D_BLAU						; BLAU 		aus	
	rcall SYSTEM_EINSTELLUNGEN_EEPROM_SPEICHERN ; SPEICHERN
	ret
; ----------------------------------------------------
; LED-ROT_INVERTIEREN								  
STEUERUNG_MENUE_EDIT_10:
	cpi temp,10
	brne STEUERUNG_MENUE_EDIT_11
	rcall ANZEIGE_ROT_INVERIEREN
	; TASTATUR	
	rcall ABFRAGE_TASTATUR_TASTE_ENTER ;OUT: FLAGS (bei ENTER-TASTE=>TASTE=0)	
	brne STEUERUNG_MENUE_EDIT_DUMMY
	; AKTION	
	LDS  temp,(adr_LED_ROT_INVERTIEREN) ; aus SRAM laden		
	andi temp,0b00000001
	com temp
	andi temp,0b00000001
	STS (adr_LED_ROT_INVERTIEREN),temp ; in SRAM speichern	
	rcall SYSTEM_EINSTELLUNGEN_EEPROM_SPEICHERN ; SPEICHERN
	ret
; ----------------------------------------------------
; ANZEIGE_FEHLER
STEUERUNG_MENUE_EDIT_11:
	cpi temp,11
	brne STEUERUNG_MENUE_EDIT_12
	rcall ANZEIGE_FEHLER
	; TASTATUR	
	rcall ABFRAGE_TASTATUR_TASTE_ENTER ;OUT: FLAGS (bei ENTER-TASTE=>TASTE=0)	
	brne STEUERUNG_MENUE_EDIT_DUMMY
	; AKTION	
	clr temp
	STS(adr_FEHLER_CODE),temp	
	ret
; ----------------------------------------------------
; MCUCSR											  
STEUERUNG_MENUE_EDIT_12:
	cpi temp,12
	brne STEUERUNG_MENUE_EDIT_13
	rcall ANZEIGE_MCUCSR
	; TASTATUR	
	rcall ABFRAGE_TASTATUR_TASTE_ENTER ;OUT: FLAGS (bei ENTER-TASTE=>TASTE=0)	
	brne STEUERUNG_MENUE_EDIT_DUMMY
	; AKTION	
	clr temp
	out MCUCSR,temp
	ret
; ----------------------------------------------------
; BETRIEBSSTUNDEN-clear								  
STEUERUNG_MENUE_EDIT_13:
	cpi temp,13
	brne STEUERUNG_MENUE_EDIT_14
	rcall ANZEIGE_BETRIEBSSTUNDEN
	; TASTATUR	
	rcall ABFRAGE_TASTATUR_TASTE_ENTER 		;OUT: FLAGS (bei ENTER-TASTE=>TASTE=0)	
	brne STEUERUNG_MENUE_EDIT_DUMMY
	; AKTION	
	rcall ANZEIGE_WAIT
	clr temp
	STS(adr_BETRIEBSSTUNDEN_hh),temp		; in SRAM speichern
	STS(adr_BETRIEBSSTUNDEN_mm),temp		; in SRAM speichern
	STS(adr_BETRIEBSSTUNDEN_ss),temp		; in SRAM speichern
	rcall SYSTEM_EINSTELLUNGEN_EEPROM_SPEICHERN ; SPEICHERN
	ret
; ----------------------------------------------------
; RESET												  
STEUERUNG_MENUE_EDIT_14:
	cpi temp,14
	brne STEUERUNG_MENUE_EDIT_15
	ldi ZH, high(TEXT_RESET*2)			; TEXT 
	ldi ZL, low (TEXT_RESET*2)
	rcall ANZEIGE_TEXT
	; TASTATUR	
	rcall ABFRAGE_TASTATUR_TASTE_ENTER ;OUT: FLAGS (bei ENTER-TASTE=>TASTE=0)	
	brne STEUERUNG_MENUE_EDIT_DUMMY
	; AKTION	
	rcall ANZEIGE_WAIT
STEUERUNG_MENUE_EDIT_14wR:
	rjmp STEUERUNG_MENUE_EDIT_14wR		; SCHLEIFE	
	ret
; ----------------------------------------------------
STEUERUNG_MENUE_EDIT_15:
	rcall ANZEIGE_LEER_MENUE			; !!!!! LEER !!!!!!

STEUERUNG_MENUE_EDIT_DUMMY:

ret
;######################################################################## 
;######################################################################## 
;######################################################################## 
; MENUE POSITIONEN LADEN												
STEUERUNG_MENUE_POSITIONEN_LADEN:
	mov temp,MENUE_0
	cpi temp, 6
	breq STEUERUNG_MENUE_POSITIONEN_LADEN_START
	ret
STEUERUNG_MENUE_POSITIONEN_LADEN_START:
	tst MENUE_1
	brne STEUERUNG_MENUE_POSITIONEN_LADEN_START_w
	ret
STEUERUNG_MENUE_POSITIONEN_LADEN_START_w:
	; LCD CLEAR
	rcall LCD_CLEAR
	; TASTATUR	
	rcall ABFRAGE_TASTATUR_TASTE_MINUS 	; OUT: FLAGS
	brne STEUERUNG_MENUE_POSITIONEN_LADEN_w
	dec MENUE_1							; -1 
STEUERUNG_MENUE_POSITIONEN_LADEN_w:
	; TASTATUR	
	rcall ABFRAGE_TASTATUR_TASTE_PLUS	; OUT: FLAGS
	brne STEUERUNG_MENUE_POSITIONEN_LADEN_ww
	inc MENUE_1							; +1 
STEUERUNG_MENUE_POSITIONEN_LADEN_ww:
	; FEHLERPRFUNG
	tst MENUE_1							; =0 ?
	brne STEUERUNG_MENUE_POSITIONEN_LADEN_www	; nein ==SPRUNG	
	inc MENUE_1							; +1 
;---------------------------------------------------------------
; HILFETEXT														
STEUERUNG_MENUE_POSITIONEN_LADEN_www:
	mov temp,MENUE_1
	; MENUE			
	cpi temp,1
	brne STEUERUNG_MENUE_POSITIONEN_LADEN_2
	rcall ANZEIGE_HILFE_PLUS_TASTE		; TASTE + bettigen
	ret
;------------------------------------------------------------
; REFERENZ A (aus EEPROM)									 
STEUERUNG_MENUE_POSITIONEN_LADEN_2:
	cpi temp,2
	brne STEUERUNG_MENUE_POSITIONEN_LADEN_3
	; TEXT anzeigen		
	ldi temp, 'A'
	rcall ANZEIGE_REFERENZ_NAME_KURZ	; INP: TEMP (REFERENZ_NUMMER=> A(EEPROM),B(EEPROM),C(EEPROM),1,2,3,4,5,6,7,8,9,10...)
	; TASTATUR abfragen	
	rcall ABFRAGE_TASTATUR_TASTE_ENTER ;OUT: FLAGS (bei ENTER-TASTE=>TASTE=0)	
	brne STEUERUNG_MENUE_POSITIONEN_LADEN_5w_DUMMY
	; REFERENZ laden	
	ldi TEMP, 'A'
	mov REFERENZ_NUMMER,temp	; A(EEPROM),B(EEPROM),C(EEPROM),1,2,3,4,5,6,7,8,9,10...
	rcall GPS_REFERENZ_LADEN	
	ret
;------------------------------------------------------------
; REFERENZ B (aus EEPROM)									 
STEUERUNG_MENUE_POSITIONEN_LADEN_3:
	cpi temp,3
	brne STEUERUNG_MENUE_POSITIONEN_LADEN_4
	; TEXT anzeigen		
	ldi temp, 'B'
	rcall ANZEIGE_REFERENZ_NAME_KURZ	; INP: TEMP (REFERENZ_NUMMER=> A(EEPROM),B(EEPROM),C(EEPROM),1,2,3,4,5,6,7,8,9,10...)
	; TASTATUR abfragen	
	rcall ABFRAGE_TASTATUR_TASTE_ENTER ;OUT: FLAGS (bei ENTER-TASTE=>TASTE=0)	
	brne STEUERUNG_MENUE_POSITIONEN_LADEN_5w_DUMMY
	; REFERENZ laden	
	ldi TEMP, 'B'
	mov REFERENZ_NUMMER,temp	; A(EEPROM),B(EEPROM),C(EEPROM),1,2,3,4,5,6,7,8,9,10...
	rcall GPS_REFERENZ_LADEN		
	ret
;------------------------------------------------------------
; REFERENZ C (aus EEPROM)									 
STEUERUNG_MENUE_POSITIONEN_LADEN_4:
	cpi temp,4
	brne STEUERUNG_MENUE_POSITIONEN_LADEN_5
	; TEXT anzeigen		
	ldi temp, 'C'
	rcall ANZEIGE_REFERENZ_NAME_KURZ	; INP: TEMP (REFERENZ_NUMMER=> A(EEPROM),B(EEPROM),C(EEPROM),1,2,3,4,5,6,7,8,9,10...)
	; TASTATUR abfragen	
	rcall ABFRAGE_TASTATUR_TASTE_ENTER ;OUT: FLAGS (bei ENTER-TASTE=>TASTE=0)	
	brne STEUERUNG_MENUE_POSITIONEN_LADEN_5w_DUMMY
	; REFERENZ laden	
	ldi TEMP, 'C'
	mov REFERENZ_NUMMER,temp	; A(EEPROM),B(EEPROM),C(EEPROM),1,2,3,4,5,6,7,8,9,10...
	rcall GPS_REFERENZ_LADEN		
	ret
;------------------------------------------------------------
; REFERENZ 1 (FEST-REFERENZ)								 
STEUERUNG_MENUE_POSITIONEN_LADEN_5:
	cpi temp,5
	brne STEUERUNG_MENUE_POSITIONEN_LADEN_6
	; TEXT anzeigen		
	ldi temp, 1
	rcall ANZEIGE_REFERENZ_NAME_KURZ	; INP: TEMP (REFERENZ_NUMMER=> A(EEPROM),B(EEPROM),C(EEPROM),1,2,3,4,5,6,7,8,9,10...)
	; TASTATUR abfragen	
	rcall ABFRAGE_TASTATUR_TASTE_ENTER ;OUT: FLAGS (bei ENTER-TASTE=>TASTE=0)	
	brne STEUERUNG_MENUE_POSITIONEN_LADEN_5w_DUMMY
	; REFERENZ laden	
	ldi TEMP, 1
	mov REFERENZ_NUMMER,temp	; A(EEPROM),B(EEPROM),C(EEPROM),1,2,3,4,5,6,7,8,9,10...
	rcall GPS_REFERENZ_LADEN
;-----------------------------------------------------------
STEUERUNG_MENUE_POSITIONEN_LADEN_5w_DUMMY:
	ret
;------------------------------------------------------------
; REFERENZ 2 (FEST-REFERENZ)								 
STEUERUNG_MENUE_POSITIONEN_LADEN_6:
	cpi temp,6
	brne STEUERUNG_MENUE_POSITIONEN_LADEN_7
	; TEXT anzeigen		
	ldi temp, 2
	rcall ANZEIGE_REFERENZ_NAME_KURZ	; INP: TEMP (REFERENZ_NUMMER=> A(EEPROM),B(EEPROM),C(EEPROM),1,2,3,4,5,6,7,8,9,10...)
	; TASTATUR abfragen	
	rcall ABFRAGE_TASTATUR_TASTE_ENTER ;OUT: FLAGS (bei ENTER-TASTE=>TASTE=0)	
	brne STEUERUNG_MENUE_POSITIONEN_LADEN_5w_DUMMY
	; REFERENZ laden	
	ldi TEMP, 2
	mov REFERENZ_NUMMER,temp	; A(EEPROM),B(EEPROM),C(EEPROM),1,2,3,4,5,6,7,8,9,10...
	rcall GPS_REFERENZ_LADEN	
	ret
;------------------------------------------------------------
; REFERENZ 3 (FEST-REFERENZ)								 
STEUERUNG_MENUE_POSITIONEN_LADEN_7:
	cpi temp,7
	brne STEUERUNG_MENUE_POSITIONEN_LADEN_8
	; TEXT anzeigen		
	ldi temp, 3
	rcall ANZEIGE_REFERENZ_NAME_KURZ	; INP: TEMP (REFERENZ_NUMMER=> A(EEPROM),B(EEPROM),C(EEPROM),1,2,3,4,5,6,7,8,9,10...)
	; TASTATUR abfragen	
	rcall ABFRAGE_TASTATUR_TASTE_ENTER ;OUT: FLAGS (bei ENTER-TASTE=>TASTE=0)	
	brne STEUERUNG_MENUE_POSITIONEN_LADEN_5w_DUMMY
	; REFERENZ laden	
	ldi TEMP, 3
	mov REFERENZ_NUMMER,temp	; A(EEPROM),B(EEPROM),C(EEPROM),1,2,3,4,5,6,7,8,9,10...
	rcall GPS_REFERENZ_LADEN
	ret
;------------------------------------------------------------
; REFERENZ 4 (FEST-REFERENZ)								 
STEUERUNG_MENUE_POSITIONEN_LADEN_8:
	cpi temp,8
	brne STEUERUNG_MENUE_POSITIONEN_LADEN_9
	; TEXT anzeigen		
	ldi temp, 4
	rcall ANZEIGE_REFERENZ_NAME_KURZ	; INP: TEMP (REFERENZ_NUMMER=> A(EEPROM),B(EEPROM),C(EEPROM),1,2,3,4,5,6,7,8,9,10...)
	; TASTATUR abfragen	
	rcall ABFRAGE_TASTATUR_TASTE_ENTER ;OUT: FLAGS (bei ENTER-TASTE=>TASTE=0)	
	brne STEUERUNG_MENUE_POSITIONEN_LADEN_5w_DUMMY
	; REFERENZ laden	
	ldi TEMP, 4
	mov REFERENZ_NUMMER,temp	; A(EEPROM),B(EEPROM),C(EEPROM),1,2,3,4,5,6,7,8,9,10...
	rcall GPS_REFERENZ_LADEN
	ret
;------------------------------------------------------------
; REFERENZ 5 (FEST-REFERENZ)								 
STEUERUNG_MENUE_POSITIONEN_LADEN_9:
	cpi temp,9
	brne STEUERUNG_MENUE_POSITIONEN_LADEN_10
	; TEXT anzeigen		
	ldi temp, 5
	rcall ANZEIGE_REFERENZ_NAME_KURZ	; INP: TEMP (REFERENZ_NUMMER=> A(EEPROM),B(EEPROM),C(EEPROM),1,2,3,4,5,6,7,8,9,10...)
	; TASTATUR abfragen	
	rcall ABFRAGE_TASTATUR_TASTE_ENTER ;OUT: FLAGS (bei ENTER-TASTE=>TASTE=0)	
	brne STEUERUNG_MENUE_POSITIONEN_LADEN_5w_DUMMY
	; REFERENZ laden	
	ldi TEMP, 5
	mov REFERENZ_NUMMER,temp	; A(EEPROM),B(EEPROM),C(EEPROM),1,2,3,4,5,6,7,8,9,10...
	rcall GPS_REFERENZ_LADEN
	ret
;------------------------------------------------------------
; REFERENZ 6 (FEST-REFERENZ)								 
STEUERUNG_MENUE_POSITIONEN_LADEN_10:
	cpi temp,10
	brne STEUERUNG_MENUE_POSITIONEN_LADEN_11
	; TEXT anzeigen		
	ldi temp, 6
	rcall ANZEIGE_REFERENZ_NAME_KURZ	; INP: TEMP (REFERENZ_NUMMER=> A(EEPROM),B(EEPROM),C(EEPROM),1,2,3,4,5,6,7,8,9,10...)
	; TASTATUR abfragen	
	rcall ABFRAGE_TASTATUR_TASTE_ENTER ;OUT: FLAGS (bei ENTER-TASTE=>TASTE=0)	
	brne STEUERUNG_MENUE_POSITIONEN_LADEN_DUMMY
	; REFERENZ laden	
	ldi TEMP, 6
	mov REFERENZ_NUMMER,temp	; A(EEPROM),B(EEPROM),C(EEPROM),1,2,3,4,5,6,7,8,9,10...
	rcall GPS_REFERENZ_LADEN
	ret
;------------------------------------------------------------
; REFERENZ 7 (FEST-REFERENZ)								 
STEUERUNG_MENUE_POSITIONEN_LADEN_11:
	cpi temp,11
	brne STEUERUNG_MENUE_POSITIONEN_LADEN_12
	; TEXT anzeigen		
	ldi temp, 7
	rcall ANZEIGE_REFERENZ_NAME_KURZ	; INP: TEMP (REFERENZ_NUMMER=> A(EEPROM),B(EEPROM),C(EEPROM),1,2,3,4,5,6,7,8,9,10...)
	; TASTATUR abfragen	
	rcall ABFRAGE_TASTATUR_TASTE_ENTER ;OUT: FLAGS (bei ENTER-TASTE=>TASTE=0)	
	brne STEUERUNG_MENUE_POSITIONEN_LADEN_DUMMY
	; REFERENZ laden	
	ldi TEMP, 7
	mov REFERENZ_NUMMER,temp	; A(EEPROM),B(EEPROM),C(EEPROM),1,2,3,4,5,6,7,8,9,10...
	rcall GPS_REFERENZ_LADEN
	ret
;------------------------------------------------------------
; REFERENZ 8 (FEST-REFERENZ)								 
STEUERUNG_MENUE_POSITIONEN_LADEN_12:
	cpi temp,12
	brne STEUERUNG_MENUE_POSITIONEN_LADEN_13
	; TEXT anzeigen		
	ldi temp, 8
	rcall ANZEIGE_REFERENZ_NAME_KURZ	; INP: TEMP (REFERENZ_NUMMER=> A(EEPROM),B(EEPROM),C(EEPROM),1,2,3,4,5,6,7,8,9,10...)
	; TASTATUR abfragen	
	rcall ABFRAGE_TASTATUR_TASTE_ENTER ;OUT: FLAGS (bei ENTER-TASTE=>TASTE=0)	
	brne STEUERUNG_MENUE_POSITIONEN_LADEN_DUMMY
	; REFERENZ laden	
	ldi TEMP, 8
	mov REFERENZ_NUMMER,temp	; A(EEPROM),B(EEPROM),C(EEPROM),1,2,3,4,5,6,7,8,9,10...
	rcall GPS_REFERENZ_LADEN
	ret
;------------------------------------------------------------
; REFERENZ 9 (FEST-REFERENZ)								 
STEUERUNG_MENUE_POSITIONEN_LADEN_13:
	cpi temp,13
	brne STEUERUNG_MENUE_POSITIONEN_LADEN_14
	; TEXT anzeigen		
	ldi temp, 9
	rcall ANZEIGE_REFERENZ_NAME_KURZ	; INP: TEMP (REFERENZ_NUMMER=> A(EEPROM),B(EEPROM),C(EEPROM),1,2,3,4,5,6,7,8,9,10...)
	; TASTATUR abfragen	
	rcall ABFRAGE_TASTATUR_TASTE_ENTER ;OUT: FLAGS (bei ENTER-TASTE=>TASTE=0)	
	brne STEUERUNG_MENUE_POSITIONEN_LADEN_DUMMY
	; REFERENZ laden	
	ldi TEMP, 9
	mov REFERENZ_NUMMER,temp	; A(EEPROM),B(EEPROM),C(EEPROM),1,2,3,4,5,6,7,8,9,10...
	rcall GPS_REFERENZ_LADEN
	ret
;------------------------------------------------------------
; REFERENZ 10 (FEST-REFERENZ)								 
STEUERUNG_MENUE_POSITIONEN_LADEN_14:
	cpi temp,14
	brne STEUERUNG_MENUE_POSITIONEN_LADEN_15
	; TEXT anzeigen		
	ldi temp, 10
	rcall ANZEIGE_REFERENZ_NAME_KURZ	; INP: TEMP (REFERENZ_NUMMER=> A(EEPROM),B(EEPROM),C(EEPROM),1,2,3,4,5,6,7,8,9,10...)
	; TASTATUR abfragen	
	rcall ABFRAGE_TASTATUR_TASTE_ENTER ;OUT: FLAGS (bei ENTER-TASTE=>TASTE=0)	
	brne STEUERUNG_MENUE_POSITIONEN_LADEN_DUMMY
	; REFERENZ laden	
	ldi TEMP, 10
	mov REFERENZ_NUMMER,temp	; A(EEPROM),B(EEPROM),C(EEPROM),1,2,3,4,5,6,7,8,9,10...
	rcall GPS_REFERENZ_LADEN
	ret
;------------------------------------------------------------
; REFERENZ 11 (FEST-REFERENZ)								 
STEUERUNG_MENUE_POSITIONEN_LADEN_15:
	cpi temp,15
	brne STEUERUNG_MENUE_POSITIONEN_LADEN_16
	; TEXT anzeigen		
	ldi temp, 11
	rcall ANZEIGE_REFERENZ_NAME_KURZ	; INP: TEMP (REFERENZ_NUMMER=> A(EEPROM),B(EEPROM),C(EEPROM),1,2,3,4,5,6,7,8,9,10...)
	; TASTATUR abfragen	
	rcall ABFRAGE_TASTATUR_TASTE_ENTER ;OUT: FLAGS (bei ENTER-TASTE=>TASTE=0)	
	brne STEUERUNG_MENUE_POSITIONEN_LADEN_DUMMY
	; REFERENZ laden	
	ldi TEMP, 11
	mov REFERENZ_NUMMER,temp	; A(EEPROM),B(EEPROM),C(EEPROM),1,2,3,4,5,6,7,8,9,10...
	rcall GPS_REFERENZ_LADEN
	ret
;------------------------------------------------------------
STEUERUNG_MENUE_POSITIONEN_LADEN_16:	
	rcall ANZEIGE_LEER_MENUE			; !!!!! LEER !!!!!! 

STEUERUNG_MENUE_POSITIONEN_LADEN_DUMMY:
ret
;######################################################################## 
;######################################################################## 
;######################################################################## 
; MENUE POSITION speichern												
STEUERUNG_MENUE_POSITIONEN_SPEICHERN:
	mov temp,MENUE_0
	cpi temp, 7
	breq STEUERUNG_MENUE_POSITIONEN_SPEICHERN_START
	ret
STEUERUNG_MENUE_POSITIONEN_SPEICHERN_START:
	tst MENUE_1
	brne STEUERUNG_MENUE_POSITIONEN_SPEICHERN_START_w
	ret
STEUERUNG_MENUE_POSITIONEN_SPEICHERN_START_w:
	; LCD CLEAR
	rcall LCD_CLEAR
	; TASTATUR	
	rcall ABFRAGE_TASTATUR_TASTE_MINUS ; OUT: FLAGS
	brne STEUERUNG_MENUE_POSITIONEN_SPEICHERN_w
	dec MENUE_1							; -1 
STEUERUNG_MENUE_POSITIONEN_SPEICHERN_w:
	; TASTATUR	
	rcall ABFRAGE_TASTATUR_TASTE_PLUS ; OUT: FLAGS
	brne STEUERUNG_MENUE_POSITIONEN_SPEICHERN_ww
	inc MENUE_1							; +1 
STEUERUNG_MENUE_POSITIONEN_SPEICHERN_ww:
	; FEHLERPRFUNG
	tst MENUE_1							; =0 ?
	brne STEUERUNG_MENUE_POSITIONEN_SPEICHERN_www	; nein ==SPRUNG	
	inc MENUE_1							; +1 
;---------------------------------------------------------------
STEUERUNG_MENUE_POSITIONEN_SPEICHERN_www:
	mov temp,MENUE_1
;---------------------------------------------------------------
; HILFETEXT														
	; MENUE			
	cpi temp,1
	brne STEUERUNG_MENUE_POSITIONEN_SPEICHERN_2
	rcall ANZEIGE_HILFE_PLUS_TASTE		; TASTE + bettigen
	ret
;------------------------------------------------------------
; REFERENZ A (IN EEPROM speichern)							 
STEUERUNG_MENUE_POSITIONEN_SPEICHERN_2:
	cpi temp,2
	brne STEUERUNG_MENUE_POSITIONEN_SPEICHERN_3
	; TEXT anzeigen		
	ldi temp, 'A'
	rcall ANZEIGE_REFERENZ_NAME_KURZ	; INP: TEMP (REFERENZ_NUMMER=> A(EEPROM),B(EEPROM),C(EEPROM),1,2,3,4,5,6,7,8,9,10...)
	; TASTATUR abfragen	
	rcall ABFRAGE_TASTATUR_TASTE_ENTER ;OUT: FLAGS (bei ENTER-TASTE=>TASTE=0)	
	brne STEUERUNG_MENUE_POSITIONEN_SPEICHERN_2w
	; REFERENZ SPEICHERN	
	ldi TEMP, 'A'							; A(EEPROM),B(EEPROM),C(EEPROM),1,2,3,4,5,6,7,8,9,10...
	rcall GPS_REFERENZ_IN_EEPROM_SPEICHERN 	; INP: TEMP ;A(EEPROM),B(EEPROM),C(EEPROM)
STEUERUNG_MENUE_POSITIONEN_SPEICHERN_2w:	
	ret
;------------------------------------------------------------
; REFERENZ B (IN EEPROM speichern)							 
STEUERUNG_MENUE_POSITIONEN_SPEICHERN_3:
	cpi temp,3
	brne STEUERUNG_MENUE_POSITIONEN_SPEICHERN_4
	; TEXT anzeigen		
	ldi temp, 'B'
	rcall ANZEIGE_REFERENZ_NAME_KURZ	; INP: TEMP (REFERENZ_NUMMER=> A(EEPROM),B(EEPROM),C(EEPROM),1,2,3,4,5,6,7,8,9,10...)
	; TASTATUR abfragen	
	rcall ABFRAGE_TASTATUR_TASTE_ENTER ;OUT: FLAGS (bei ENTER-TASTE=>TASTE=0)	
	brne STEUERUNG_MENUE_POSITIONEN_SPEICHERN_3w
	; REFERENZ SPEICHERN	
	ldi TEMP, 'B'						; A(EEPROM),B(EEPROM),C(EEPROM),1,2,3,4,5,6,7,8,9,10...
	rcall GPS_REFERENZ_IN_EEPROM_SPEICHERN 	; INP: TEMP ;A(EEPROM),B(EEPROM),C(EEPROM)	
STEUERUNG_MENUE_POSITIONEN_SPEICHERN_3w:	
	ret
;------------------------------------------------------------
; REFERENZ C (IN EEPROM speichern)							 
STEUERUNG_MENUE_POSITIONEN_SPEICHERN_4:
	cpi temp,4
	brne STEUERUNG_MENUE_POSITIONEN_SPEICHERN_5
	; TEXT anzeigen		
	ldi temp, 'C'
	rcall ANZEIGE_REFERENZ_NAME_KURZ	; INP: TEMP (REFERENZ_NUMMER=> A(EEPROM),B(EEPROM),C(EEPROM),1,2,3,4,5,6,7,8,9,10...)
	; TASTATUR abfragen	
	rcall ABFRAGE_TASTATUR_TASTE_ENTER ;OUT: FLAGS (bei ENTER-TASTE=>TASTE=0)	
	brne STEUERUNG_MENUE_POSITIONEN_SPEICHERN_4w
	; REFERENZ SPEICHERN	
	ldi TEMP, 'C'						; A(EEPROM),B(EEPROM),C(EEPROM),1,2,3,4,5,6,7,8,9,10...
	rcall GPS_REFERENZ_IN_EEPROM_SPEICHERN 	; INP: TEMP ;A(EEPROM),B(EEPROM),C(EEPROM)	
STEUERUNG_MENUE_POSITIONEN_SPEICHERN_4w:	
	ret
;------------------------------------------------------------
STEUERUNG_MENUE_POSITIONEN_SPEICHERN_5:
	rcall ANZEIGE_LEER_MENUE			; !!!!! LEER !!!!!! 

ret
;######################################################################## 
;######################################################################## 
;######################################################################## 
PROGRAMMSTARTS_ZAEHLEN:
	LDS ZL,(adr_ANZ_PROGRAMMSTARTS_L)	; aus SRAM laden	
	LDS ZH,(adr_ANZ_PROGRAMMSTARTS_H)
	adiw ZL,1
	STS (adr_ANZ_PROGRAMMSTARTS_L),ZL	; in SRAM speichern 
	STS (adr_ANZ_PROGRAMMSTARTS_H),ZH

	rcall SYSTEM_EINSTELLUNGEN_EEPROM_SPEICHERN
ret
;##############################################################################
;##############################################################################
;##############################################################################
;																			   
; INPUT: REFERENZ_NUMMER ;A(EEPROM),B(EEPROM),C(EEPROM),1,2,3,4,5,6,7,8,9,10...
; 																			   
GPS_REFERENZ_LADEN:
	mov temp, REFERENZ_NUMMER ;A(EEPROM),B(EEPROM),C(EEPROM),1,2,3,4,5,6,7,8,9,10...
GPS_REFERENZ_LADEN_wA:
	cpi temp, 'A'
	brne GPS_REFERENZ_LADEN_wB
	rjmp GPS_REFERENZ_LADEN_A
GPS_REFERENZ_LADEN_wB:
	cpi temp, 'B'
	brne GPS_REFERENZ_LADEN_wC
	rjmp GPS_REFERENZ_LADEN_B
GPS_REFERENZ_LADEN_wC:
	cpi temp, 'C'
	brne GPS_REFERENZ_LADEN_w1
	rjmp GPS_REFERENZ_LADEN_C
GPS_REFERENZ_LADEN_w1:
	cpi temp, 1
	brne GPS_REFERENZ_LADEN_w2
	rjmp GPS_REFERENZ_LADEN_01
GPS_REFERENZ_LADEN_w2:
	cpi temp, 2
	brne GPS_REFERENZ_LADEN_w3
	rjmp GPS_REFERENZ_LADEN_02
GPS_REFERENZ_LADEN_w3:
	cpi temp, 3
	brne GPS_REFERENZ_LADEN_w4
	rjmp GPS_REFERENZ_LADEN_03
GPS_REFERENZ_LADEN_w4:
	cpi temp, 4
	brne GPS_REFERENZ_LADEN_w5
	rjmp GPS_REFERENZ_LADEN_04
GPS_REFERENZ_LADEN_w5:
	cpi temp, 5
	brne GPS_REFERENZ_LADEN_w6
	rjmp GPS_REFERENZ_LADEN_05
GPS_REFERENZ_LADEN_w6:
	cpi temp, 6
	brne GPS_REFERENZ_LADEN_w7
	rjmp GPS_REFERENZ_LADEN_06
GPS_REFERENZ_LADEN_w7:
	cpi temp, 7
	brne GPS_REFERENZ_LADEN_w8
	rjmp GPS_REFERENZ_LADEN_07
GPS_REFERENZ_LADEN_w8:
	cpi temp, 8
	brne GPS_REFERENZ_LADEN_w9
	rjmp GPS_REFERENZ_LADEN_08
GPS_REFERENZ_LADEN_w9:
	cpi temp, 9
	brne GPS_REFERENZ_LADEN_w10
	rjmp GPS_REFERENZ_LADEN_09
GPS_REFERENZ_LADEN_w10:
	cpi temp, 10
	brne GPS_REFERENZ_LADEN_w11
	rjmp GPS_REFERENZ_LADEN_10
GPS_REFERENZ_LADEN_w11:
	cpi temp, 11
	brne GPS_REFERENZ_LADEN_w12
	rjmp GPS_REFERENZ_LADEN_11
GPS_REFERENZ_LADEN_w12:
	; FEHLER
	ldi temp, 1
	mov REFERENZ_NUMMER,temp ;A(EEPROM),B(EEPROM),C(EEPROM),1,2,3,4,5,6,7,8,9,10...
	rjmp GPS_REFERENZ_LADEN	 ; ===> SPRUNG (erneuter Versuch)	


GPS_REFERENZ_LADEN_A:
	rcall GPS_REFERENZ_AUS_EEPROM_LADEN ; INP: REFERENZ_NUMMER ;A(EEPROM),B(EEPROM),C(EEPROM)
	ret
GPS_REFERENZ_LADEN_B:
	rcall GPS_REFERENZ_AUS_EEPROM_LADEN ; INP: REFERENZ_NUMMER ;A(EEPROM),B(EEPROM),C(EEPROM)
	ret
GPS_REFERENZ_LADEN_C:
	rcall GPS_REFERENZ_AUS_EEPROM_LADEN ; INP: REFERENZ_NUMMER ;A(EEPROM),B(EEPROM),C(EEPROM)
	ret
GPS_REFERENZ_LADEN_01:
	ldi ZH, high(DATEN_REFERENZ_1*2)	; DATEN	- ZEIGER-initialisieren	
	ldi ZL, low (DATEN_REFERENZ_1*2)
	rcall REFERENZ_FEST_UEBERNEHMEN
	ret
GPS_REFERENZ_LADEN_02:
	ldi ZH, high(DATEN_REFERENZ_2*2)	; DATEN	- ZEIGER-initialisieren	
	ldi ZL, low (DATEN_REFERENZ_2*2)
	rcall REFERENZ_FEST_UEBERNEHMEN
	ret
GPS_REFERENZ_LADEN_03:
	ldi ZH, high(DATEN_REFERENZ_3*2)	; DATEN	- ZEIGER-initialisieren	
	ldi ZL, low (DATEN_REFERENZ_3*2)
	rcall REFERENZ_FEST_UEBERNEHMEN
	ret
GPS_REFERENZ_LADEN_04:
	ldi ZH, high(DATEN_REFERENZ_4*2)	; DATEN	- ZEIGER-initialisieren	
	ldi ZL, low (DATEN_REFERENZ_4*2)
	rcall REFERENZ_FEST_UEBERNEHMEN
	ret
GPS_REFERENZ_LADEN_05:
	ldi ZH, high(DATEN_REFERENZ_5*2)	; DATEN	- ZEIGER-initialisieren	
	ldi ZL, low (DATEN_REFERENZ_5*2)
	rcall REFERENZ_FEST_UEBERNEHMEN
	ret
GPS_REFERENZ_LADEN_06:
	ldi ZH, high(DATEN_REFERENZ_6*2)	; DATEN	- ZEIGER-initialisieren	
	ldi ZL, low (DATEN_REFERENZ_6*2)
	rcall REFERENZ_FEST_UEBERNEHMEN
	ret
GPS_REFERENZ_LADEN_07:
	ldi ZH, high(DATEN_REFERENZ_7*2)	; DATEN	- ZEIGER-initialisieren	
	ldi ZL, low (DATEN_REFERENZ_7*2)
	rcall REFERENZ_FEST_UEBERNEHMEN
	ret
GPS_REFERENZ_LADEN_08:
	ldi ZH, high(DATEN_REFERENZ_8*2)	; DATEN	- ZEIGER-initialisieren	
	ldi ZL, low (DATEN_REFERENZ_8*2)
	rcall REFERENZ_FEST_UEBERNEHMEN
	ret
GPS_REFERENZ_LADEN_09:
	ldi ZH, high(DATEN_REFERENZ_9*2)	; DATEN	- ZEIGER-initialisieren	
	ldi ZL, low (DATEN_REFERENZ_9*2)
	rcall REFERENZ_FEST_UEBERNEHMEN
	ret
GPS_REFERENZ_LADEN_10:
	ldi ZH, high(DATEN_REFERENZ_10*2)	; DATEN	- ZEIGER-initialisieren	
	ldi ZL, low (DATEN_REFERENZ_10*2)
	rcall REFERENZ_FEST_UEBERNEHMEN
	ret
GPS_REFERENZ_LADEN_11:
	ldi ZH, high(DATEN_REFERENZ_11*2)	; DATEN	- ZEIGER-initialisieren	
	ldi ZL, low (DATEN_REFERENZ_11*2)
	rcall REFERENZ_FEST_UEBERNEHMEN
ret
;######################################################################## 
;######################################################################## 
;######################################################################## 
; INPUT: ZL+ZH (ZEIGERPOSITION) DATEN 									  
REFERENZ_FEST_UEBERNEHMEN:
	; X - LNGE		
	lpm temp, Z+								; 	aus TABELLE auslesen und ZEIGER +1		
	STS(adr_GPS_REFERENZ_X_LAENGE_BYTE1),temp	; BYTE1 in SRAM speichern					
	lpm temp, Z+								; 	aus TABELLE auslesen und ZEIGER +1		
	STS(adr_GPS_REFERENZ_X_LAENGE_BYTE2),temp	; BYTE2 in SRAM speichern					
	lpm temp, Z+								; 	aus TABELLE auslesen und ZEIGER +1		
	STS(adr_GPS_REFERENZ_X_LAENGE_BYTE3),temp	; BYTE3 in SRAM speichern					
	lpm temp, Z+								; 	aus TABELLE auslesen und ZEIGER +1		
	STS(adr_GPS_REFERENZ_X_LAENGE_BYTE4),temp	; BYTE4 in SRAM speichern					
	; Y - BREITE 	
	lpm temp, Z+								; 	aus TABELLE auslesen und ZEIGER +1		
	STS(adr_GPS_REFERENZ_Y_BREITE_BYTE1),temp	; BYTE1 in SRAM speichern					
	lpm temp, Z+								; 	aus TABELLE auslesen und ZEIGER +1		
	STS(adr_GPS_REFERENZ_Y_BREITE_BYTE2),temp	; BYTE2 in SRAM speichern					
	lpm temp, Z+								; 	aus TABELLE auslesen und ZEIGER +1		
	STS(adr_GPS_REFERENZ_Y_BREITE_BYTE3),temp	; BYTE3 in SRAM speichern					
	lpm temp, Z+								; 	aus TABELLE auslesen und ZEIGER +1		
	STS(adr_GPS_REFERENZ_Y_BREITE_BYTE4),temp	; BYTE4 in SRAM speichern					
	; HHE			
	lpm temp, Z+								; 	aus TABELLE auslesen und ZEIGER +1		
	STS(adr_GPS_REFERENZ_HOEHE_L),temp			; LOW in SRAM speichern						
	lpm temp, Z+								; 	aus TABELLE auslesen und ZEIGER +1		
	STS(adr_GPS_REFERENZ_HOEHE_H),temp			; HIHG in SRAM speichern					
	lpm temp, Z+								; 	aus TABELLE auslesen und ZEIGER +1		
	lpm temp, Z+								; 	aus TABELLE auslesen und ZEIGER +1		


	rcall ANZEIGE_TEXT_NEUE_REFERENZ			; neue REFERENZ 
	rcall wait_1s
	rcall SYSTEM_EINSTELLUNGEN_EEPROM_SPEICHERN

	clr TASTE
	clr MENUE_0
	clr MENUE_1

ret
;##############################################################################
;##############################################################################
;##############################################################################
;																			   
; INPUT: TEMP ;A(EEPROM),B(EEPROM),C(EEPROM),1,2,3,4,5,6,7,8,9,10...		   
; 																			   
;	rcall GPS_REFERENZ_IN_EEPROM_SPEICHERN ; INP: TEMP ;A(EEPROM),B(EEPROM),C(EEPROM)
; 																			   
GPS_REFERENZ_IN_EEPROM_SPEICHERN:
	cpi temp,'A'		
	breq GPS_REFERENZ_IN_EEPROM_SPEICHERN_A
	cpi temp,'B'		
	breq GPS_REFERENZ_IN_EEPROM_SPEICHERN_B
	cpi temp,'C'		
	breq GPS_REFERENZ_IN_EEPROM_SPEICHERN_C
	; FEHLER	
	rcall ANZEIGE_TEXT_ERROR
	rcall wait_1s
	ret	
;----------------------------------------------
GPS_REFERENZ_IN_EEPROM_SPEICHERN_A:
	; EEPROM ADRESSE initalisieren	
	LDI ZL, LOW(adr_EEPROM_REF_A_X_LAENGE_BYTE1)	; ADRESSE INITIALISIEREN	
	LDI ZH,HIGH(adr_EEPROM_REF_A_X_LAENGE_BYTE1)	; ADRESSE INITIALISIEREN	
	rjmp GPS_REFERENZ_IN_EEPROM_SPEICHERN_FERTIG
;----------------------------------------------
GPS_REFERENZ_IN_EEPROM_SPEICHERN_B:
	; EEPROM ADRESSE initalisieren	
	LDI ZL, LOW(adr_EEPROM_REF_B_X_LAENGE_BYTE1)	; ADRESSE INITIALISIEREN	
	LDI ZH,HIGH(adr_EEPROM_REF_B_X_LAENGE_BYTE1)	; ADRESSE INITIALISIEREN	
	rjmp GPS_REFERENZ_IN_EEPROM_SPEICHERN_FERTIG
;----------------------------------------------
GPS_REFERENZ_IN_EEPROM_SPEICHERN_C:
	; EEPROM ADRESSE initalisieren	
	LDI ZL, LOW(adr_EEPROM_REF_C_X_LAENGE_BYTE1)	; ADRESSE INITIALISIEREN	
	LDI ZH,HIGH(adr_EEPROM_REF_C_X_LAENGE_BYTE1)	; ADRESSE INITIALISIEREN	
	rjmp GPS_REFERENZ_IN_EEPROM_SPEICHERN_FERTIG
;----------------------------------------------
GPS_REFERENZ_IN_EEPROM_SPEICHERN_FERTIG:
	; SPEICHERN X-LNGE			
	LDS temp,(adr_GPS_X_LAENGE_BYTE1)			; aus SRAM laden	
	rcall EEPROM_WRITE_PLUS						; INP: TEMP(DATEN) ZL+ZH(ADRESSE) (Z+1)	
	LDS temp,(adr_GPS_X_LAENGE_BYTE2)			; aus SRAM laden	
	rcall EEPROM_WRITE_PLUS						; INP: TEMP(DATEN) ZL+ZH(ADRESSE) (Z+1)	
	LDS temp,(adr_GPS_X_LAENGE_BYTE3)			; aus SRAM laden	
	rcall EEPROM_WRITE_PLUS						; INP: TEMP(DATEN) ZL+ZH(ADRESSE) (Z+1)	
	LDS temp,(adr_GPS_X_LAENGE_BYTE4)			; aus SRAM laden	
	rcall EEPROM_WRITE_PLUS						; INP: TEMP(DATEN) ZL+ZH(ADRESSE) (Z+1)	
	; SPEICHERN Y-BREITE		
	LDS temp,(adr_GPS_Y_BREITE_BYTE1)			; aus SRAM laden	
	rcall EEPROM_WRITE_PLUS						; INP: TEMP(DATEN) ZL+ZH(ADRESSE) (Z+1)	
	LDS temp,(adr_GPS_Y_BREITE_BYTE2)			; aus SRAM laden	
	rcall EEPROM_WRITE_PLUS						; INP: TEMP(DATEN) ZL+ZH(ADRESSE) (Z+1)	
	LDS temp,(adr_GPS_Y_BREITE_BYTE3)			; aus SRAM laden	
	rcall EEPROM_WRITE_PLUS						; INP: TEMP(DATEN) ZL+ZH(ADRESSE) (Z+1)	
	LDS temp,(adr_GPS_Y_BREITE_BYTE4)			; aus SRAM laden	
	rcall EEPROM_WRITE_PLUS						; INP: TEMP(DATEN) ZL+ZH(ADRESSE) (Z+1)	
	; SPEICHERN HHE			
	LDS temp,(adr_GPS_HOEHE_L)					; aus SRAM laden	
	rcall EEPROM_WRITE_PLUS						; INP: TEMP(DATEN) ZL+ZH(ADRESSE) (Z+1)	
	LDS temp,(adr_GPS_HOEHE_H)					; aus SRAM laden	
	rcall EEPROM_WRITE_PLUS						; INP: TEMP(DATEN) ZL+ZH(ADRESSE) (Z+1)	
	; SPEICHERN DATUM
	LDS temp,(adr_GPS_TAG)							; aus SRAM laden	
	rcall EEPROM_WRITE_PLUS						; INP: TEMP(DATEN) ZL+ZH(ADRESSE) (Z+1)	
	LDS temp,(adr_GPS_MONAT)						; aus SRAM laden	
	rcall EEPROM_WRITE_PLUS						; INP: TEMP(DATEN) ZL+ZH(ADRESSE) (Z+1)	
	LDS temp,(adr_GPS_JAHR)							; aus SRAM laden	
	rcall EEPROM_WRITE_PLUS						; INP: TEMP(DATEN) ZL+ZH(ADRESSE) (Z+1)	
	; SPEICHERN ZEIT	
	LDS temp,(adr_GPS_hh)							; aus SRAM laden	
	rcall EEPROM_WRITE_PLUS						; INP: TEMP(DATEN) ZL+ZH(ADRESSE) (Z+1)	
	LDS temp,(adr_GPS_mm)							; aus SRAM laden	
	rcall EEPROM_WRITE_PLUS						; INP: TEMP(DATEN) ZL+ZH(ADRESSE) (Z+1)	
	LDS temp,(adr_GPS_ss)							; aus SRAM laden	
	rcall EEPROM_WRITE_PLUS						; INP: TEMP(DATEN) ZL+ZH(ADRESSE) (Z+1)	

	rcall ANZEIGE_TEXT_GESPEICHERT
	clr TASTE
	clr MENUE_0
	clr MENUE_1
ret
##############################################################################
;##############################################################################
;##############################################################################
;																			   		
; INPUT: TEMP ;A(EEPROM),B(EEPROM),C(EEPROM)								   		
; 																			   		
;	rcall GPS_REFERENZ_AUS_EEPROM_LADEN ; INP: TEMP ;A(EEPROM),B(EEPROM),C(EEPROM)	
; 																			   		
; 																			   		
GPS_REFERENZ_AUS_EEPROM_LADEN:
	mov temp, REFERENZ_NUMMER ;A(EEPROM),B(EEPROM),C(EEPROM),1,2,3,4,5,6,7,8,9,10...
	cpi temp,'A'		
	breq GPS_REFERENZ_AUS_EEPROM_LADEN_A
	cpi temp,'B'		
	breq GPS_REFERENZ_AUS_EEPROM_LADEN_B
	cpi temp,'C'		
	breq GPS_REFERENZ_AUS_EEPROM_LADEN_C
	; FEHLER	
	rcall ANZEIGE_TEXT_ERROR
;	rcall wait_1s
	ret	
;----------------------------------------------
GPS_REFERENZ_AUS_EEPROM_LADEN_A:
	; EEPROM ADRESSE initalisieren	
	LDI ZL, LOW(adr_EEPROM_REF_A_X_LAENGE_BYTE1)	; ADRESSE INITIALISIEREN	
	LDI ZH,HIGH(adr_EEPROM_REF_A_X_LAENGE_BYTE1)	; ADRESSE INITIALISIEREN	
	rjmp GPS_REFERENZ_AUS_EEPROM_LADEN_FERTIG
;----------------------------------------------
GPS_REFERENZ_AUS_EEPROM_LADEN_B:
	; EEPROM ADRESSE initalisieren	
	LDI ZL, LOW(adr_EEPROM_REF_B_X_LAENGE_BYTE1)	; ADRESSE INITIALISIEREN	
	LDI ZH,HIGH(adr_EEPROM_REF_B_X_LAENGE_BYTE1)	; ADRESSE INITIALISIEREN	
	rjmp GPS_REFERENZ_AUS_EEPROM_LADEN_FERTIG
;----------------------------------------------
GPS_REFERENZ_AUS_EEPROM_LADEN_C:
	; EEPROM ADRESSE initalisieren	
	LDI ZL, LOW(adr_EEPROM_REF_C_X_LAENGE_BYTE1)	; ADRESSE INITIALISIEREN	
	LDI ZH,HIGH(adr_EEPROM_REF_C_X_LAENGE_BYTE1)	; ADRESSE INITIALISIEREN	
	rjmp GPS_REFERENZ_AUS_EEPROM_LADEN_FERTIG
;----------------------------------------------
GPS_REFERENZ_AUS_EEPROM_LADEN_FERTIG:
	; AUSLESEN X-LNGE			
	rcall EEPROM_READ_PLUS 					; INP: ZL+ZH(ADRESSE) OUT: TEMP (DATEN) (Z +1)	
	STS(adr_GPS_REFERENZ_X_LAENGE_BYTE1),temp
	rcall EEPROM_READ_PLUS 					; INP: ZL+ZH(ADRESSE) OUT: TEMP (DATEN) (Z +1)	
	STS(adr_GPS_REFERENZ_X_LAENGE_BYTE2),temp
	rcall EEPROM_READ_PLUS 					; INP: ZL+ZH(ADRESSE) OUT: TEMP (DATEN) (Z +1)	
	STS(adr_GPS_REFERENZ_X_LAENGE_BYTE3),temp
	rcall EEPROM_READ_PLUS 					; INP: ZL+ZH(ADRESSE) OUT: TEMP (DATEN) (Z +1)	
	STS(adr_GPS_REFERENZ_X_LAENGE_BYTE4),temp
	; AUSLESEN Y-BREITE		
	rcall EEPROM_READ_PLUS 					; INP: ZL+ZH(ADRESSE) OUT: TEMP (DATEN) (Z +1)	
	STS(adr_GPS_REFERENZ_Y_BREITE_BYTE1),temp
	rcall EEPROM_READ_PLUS 					; INP: ZL+ZH(ADRESSE) OUT: TEMP (DATEN) (Z +1)	
	STS(adr_GPS_REFERENZ_Y_BREITE_BYTE2),temp
	rcall EEPROM_READ_PLUS 					; INP: ZL+ZH(ADRESSE) OUT: TEMP (DATEN) (Z +1)	
	STS(adr_GPS_REFERENZ_Y_BREITE_BYTE3),temp
	rcall EEPROM_READ_PLUS 					; INP: ZL+ZH(ADRESSE) OUT: TEMP (DATEN) (Z +1)	
	STS(adr_GPS_REFERENZ_Y_BREITE_BYTE4),temp
	; AUSLESEN HHE			
	rcall EEPROM_READ_PLUS 					; INP: ZL+ZH(ADRESSE) OUT: TEMP (DATEN) (Z +1)	
	STS(adr_GPS_REFERENZ_HOEHE_L),temp
	rcall EEPROM_READ_PLUS 					; INP: ZL+ZH(ADRESSE) OUT: TEMP (DATEN) (Z +1)	
	STS(adr_GPS_REFERENZ_HOEHE_H),temp		
	; AUSLESEN DATUM
	rcall EEPROM_READ_PLUS 					; INP: ZL+ZH(ADRESSE) OUT: TEMP (DATEN) (Z +1)	
	; temp ??				
	rcall EEPROM_READ_PLUS 					; INP: ZL+ZH(ADRESSE) OUT: TEMP (DATEN) (Z +1)	
	; temp ??				
	rcall EEPROM_READ_PLUS 					; INP: ZL+ZH(ADRESSE) OUT: TEMP (DATEN) (Z +1)	
	; temp ??				
	; AUSLESEN ZEIT	
	rcall EEPROM_READ_PLUS 					; INP: ZL+ZH(ADRESSE) OUT: TEMP (DATEN) (Z +1)	
	; temp ??				
	rcall EEPROM_READ_PLUS 					; INP: ZL+ZH(ADRESSE) OUT: TEMP (DATEN) (Z +1)	
	; temp ??				
	rcall EEPROM_READ_PLUS 					; INP: ZL+ZH(ADRESSE) OUT: TEMP (DATEN) (Z +1)	
	; temp ??				




	rcall ANZEIGE_TEXT_NEUE_REFERENZ			; neue REFERENZ 

	rcall wait_1s
		
	rcall SYSTEM_EINSTELLUNGEN_EEPROM_SPEICHERN

	clr TASTE
	clr MENUE_0
	clr MENUE_1
ret
;######################################################################## 
;######################################################################## 
;######################################################################## 
; adr_EEPROM_ANZ_PROGRAMMSTARTS_L=0			; ANZAHL PROGRAMMSTARTS L	
; adr_EEPROM_ANZ_PROGRAMMSTARTS_H=1			; ANZAHL PROGRAMMSTARTS H	
; adr_EEPROM_REFERENZ_NUMMER	=2			; letzte Geladene REFERENZ	
; adr_EEPROM_HOEHE_OFFSET_L	    =3			; OFFSET HHE L				
; adr_EEPROM_HOEHE_OFFSET_H		=4			; OFFSET HHE H				
; adr_EEPROM_LED_LCD_ON			=5			; LED-LCD					
; adr_EEPROM_LED_ROT_ON			=6			; LED-ROT					
; adr_EEPROM_LED_BLAU_ON		=7			; LED-BLAU					
; adr_EEPROM_LED_ROT_INVERTIEREN=8			; LED-ROT 0=ROT an bei V 1=ROT an bei A 
; adr_EEPROM_BETRIEBSSTUNDEN_hh	=9			; Betriebsstunden			
; adr_EEPROM_BETRIEBSSTUNDEN_mm	=10			; Betriebsstunden			
; adr_EEPROM_BETRIEBSSTUNDEN_ss	=11			; Betriebsstunden			
SYSTEM_EINSTELLUNGEN_EEPROM_SPEICHERN:
	rcall wait_100ms
	rcall ANZEIGE_WAIT
	rcall wait_100ms
	; EEPROM ADRESSE initalisieren	
	LDI ZL, LOW(adr_EEPROM_ANZ_PROGRAMMSTARTS_L)
	LDI ZH,HIGH(adr_EEPROM_ANZ_PROGRAMMSTARTS_L)
	; 0 SPEICHERN adr_ANZ_PROGRAMMSTARTS_L
	LDS temp,(adr_ANZ_PROGRAMMSTARTS_L)
	rcall EEPROM_WRITE_PLUS					; INP: TEMP(DATEN) ZL+ZH(ADRESSE) (Z+1)	
	; 1 SPEICHERN adr_ANZ_PROGRAMMSTARTS_H
	LDS temp,(adr_ANZ_PROGRAMMSTARTS_H)
	rcall EEPROM_WRITE_PLUS					; INP: TEMP(DATEN) ZL+ZH(ADRESSE) (Z+1)	
	; 2 SPEICHERN REFERENZ_NUMMER	; A(EEPROM),B(EEPROM),C(EEPROM),1,2,3,4,5,6,7,8,9,10...	
	mov temp,REFERENZ_NUMMER			
	rcall EEPROM_WRITE_PLUS					; INP: TEMP(DATEN) ZL+ZH(ADRESSE) (Z+1)	
	; 3 SPEICHERN OFFSET HHE L
	LDS temp,(adr_GPS_HOEHE_OFFSET_L)
	rcall EEPROM_WRITE_PLUS					; INP: TEMP(DATEN) ZL+ZH(ADRESSE) (Z+1)	
	; 4 SPEICHERN OFFSET HHE H				
	LDS temp,(adr_GPS_HOEHE_OFFSET_H)
	rcall EEPROM_WRITE_PLUS					; INP: TEMP(DATEN) ZL+ZH(ADRESSE) (Z+1)	
	; 5 SPEICHERN LED_LCD_ON(LED_C_LCD)		
	clr temp
	sbic DDRC,LED_C_LCD
 	ldi temp,1
	rcall EEPROM_WRITE_PLUS					; INP: TEMP(DATEN) ZL+ZH(ADRESSE) (Z+1)	
	; 6 SPEICHERN LED_ROT_ON (LED_D_ROT)	
	clr temp
	sbic DDRD,LED_D_ROT
 	ldi temp,1
	rcall EEPROM_WRITE_PLUS					; INP: TEMP(DATEN) ZL+ZH(ADRESSE) (Z+1)	
	; 7 SPEICHERN LED_BLAU_ON (LED_D_BLAU)	
	clr temp
	sbic DDRD,LED_D_BLAU
 	ldi temp,1
	rcall EEPROM_WRITE_PLUS					; INP: TEMP(DATEN) ZL+ZH(ADRESSE) (Z+1)	
	; 8 SPEICHERN LED_ROT_INVERTIEREN		
	LDS temp,(adr_LED_ROT_INVERTIEREN)	
	rcall EEPROM_WRITE_PLUS					; INP: TEMP(DATEN) ZL+ZH(ADRESSE) (Z+1)	
	; 9  SPEICHERN BETRIEBSSTUNDEN-hh		
	LDS temp,(adr_BETRIEBSSTUNDEN_hh)	
	rcall EEPROM_WRITE_PLUS					; INP: TEMP(DATEN) ZL+ZH(ADRESSE) (Z+1)	
	; 10 SPEICHERN BETRIEBSSTUNDEN-mm		
	LDS temp,(adr_BETRIEBSSTUNDEN_mm)	
	rcall EEPROM_WRITE_PLUS					; INP: TEMP(DATEN) ZL+ZH(ADRESSE) (Z+1)	
	; 11 SPEICHERN BETRIEBSSTUNDEN-ss		
	LDS temp,(adr_BETRIEBSSTUNDEN_ss)	
	rcall EEPROM_WRITE_PLUS					; INP: TEMP(DATEN) ZL+ZH(ADRESSE) (Z+1)	

ret
;######################################################################## 
;######################################################################## 
;######################################################################## 
; adr_EEPROM_ANZ_PROGRAMMSTARTS_L=0			; ANZAHL PROGRAMMSTARTS L	
; adr_EEPROM_ANZ_PROGRAMMSTARTS_H=1			; ANZAHL PROGRAMMSTARTS H	
; adr_EEPROM_REFERENZ_NUMMER	=2			; letzte Geladene REFERENZ	
; adr_EEPROM_HOEHE_OFFSET_L	    =3			; OFFSET HHE L				
; adr_EEPROM_HOEHE_OFFSET_H		=4			; OFFSET HHE H				
; adr_EEPROM_LED_LCD_ON			=5			; LED-LCD					
; adr_EEPROM_LED_ROT_ON			=6			; LED-ROT					
; adr_EEPROM_LED_BLAU_ON		=7			; LED-BLAU					
; adr_EEPROM_LED_ROT_INVERTIEREN=8			; LED-ROT 0=ROT an bei V 1=ROT an bei A 
; adr_EEPROM_BETRIEBSSTUNDEN_hh	=9			; Betriebsstunden			
; adr_EEPROM_BETRIEBSSTUNDEN_mm	=10			; Betriebsstunden			
; adr_EEPROM_BETRIEBSSTUNDEN_ss	=11			; Betriebsstunden			
SYSTEM_EINSTELLUNGEN_EEPROM_LADEN:
	; EEPROM ADRESSE initalisieren		
	LDI ZL, LOW(adr_EEPROM_ANZ_PROGRAMMSTARTS_L)	; ADRESSE INITIALISIEREN	
	LDI ZH,HIGH(adr_EEPROM_ANZ_PROGRAMMSTARTS_L)	; ADRESSE INITIALISIEREN	
	; 0 DATEN auslesen adr_EEPROM_ANZ_PROGRAMMSTARTS_L
	rcall EEPROM_READ_PLUS 					; INP: ZL+ZH(ADRESSE) OUT: TEMP (DATEN) (Z +1)	
	STS(adr_ANZ_PROGRAMMSTARTS_L),temp
	; 1 DATEN auslesen adr_EEPROM_ANZ_PROGRAMMSTARTS_H
	rcall EEPROM_READ_PLUS 					; INP: ZL+ZH(ADRESSE) OUT: TEMP (DATEN) (Z +1)	
	STS(adr_ANZ_PROGRAMMSTARTS_H),temp
	; 2 DATEN auslesen adr_EEPROM_REFERENZ_NUMMER; A(EEPROM),B(EEPROM),C(EEPROM),1,2,3,4,5,6,7,8,9,10...	
	rcall EEPROM_READ_PLUS 					; INP: ZL+ZH(ADRESSE) OUT: TEMP (DATEN) (Z +1)	
	mov REFERENZ_NUMMER,temp				
	; 3 DATEN auslesen adr_EEPROM_HOEHE_OFFSET_L
	rcall EEPROM_READ_PLUS 					; INP: ZL+ZH(ADRESSE) OUT: TEMP (DATEN) (Z +1)	
	STS(adr_GPS_HOEHE_OFFSET_L),temp
	; 4 DATEN auslesen adr_EEPROM_HOEHE_OFFSET_H
	rcall EEPROM_READ_PLUS 					; INP: ZL+ZH(ADRESSE) OUT: TEMP (DATEN) (Z +1)	
	STS(adr_GPS_HOEHE_OFFSET_H),temp
	; 5 DATEN auslesen LED_LCD_ON; PIN 3 LCD
	rcall EEPROM_READ_PLUS 					; INP: ZL+ZH(ADRESSE) OUT: TEMP (DATEN) (Z +1)	
	tst temp
	brne SYSTEM_EINSTELLUNGEN_EEPROM_LADEN_LCD
	cbi DDRC, LED_C_LCD	    				; PIN ==> EINGANG
SYSTEM_EINSTELLUNGEN_EEPROM_LADEN_LCD:
	; 6 DATEN auslesen LED_ROT_ON; PIN 6 LED
	rcall EEPROM_READ_PLUS 					; INP: ZL+ZH(ADRESSE) OUT: TEMP (DATEN) (Z +1)	
	tst temp
	brne SYSTEM_EINSTELLUNGEN_EEPROM_LADEN_ROT
	cbi DDRD, LED_D_ROT	    				; PIN ==> EINGANG
SYSTEM_EINSTELLUNGEN_EEPROM_LADEN_ROT:
	; 7 DATEN auslesen LED_BLAU_ON;PIN 7 LED
	rcall EEPROM_READ_PLUS 					; INP: ZL+ZH(ADRESSE) OUT: TEMP (DATEN) (Z +1)	
	tst temp
	brne SYSTEM_EINSTELLUNGEN_EEPROM_LADEN_BLAU
	cbi DDRD, LED_D_BLAU    				; PIN ==> EINGANG
SYSTEM_EINSTELLUNGEN_EEPROM_LADEN_BLAU:
	; 8 DATEN auslesen LED_ROT_INVERTIEREN
	rcall EEPROM_READ_PLUS 					; INP: ZL+ZH(ADRESSE) OUT: TEMP (DATEN) (Z +1)	
	STS(adr_LED_ROT_INVERTIEREN),temp
	; 9 DATEN auslesen BETRIEBSSTUNDEN-hh
	rcall EEPROM_READ_PLUS 					; INP: ZL+ZH(ADRESSE) OUT: TEMP (DATEN) (Z +1)	
	STS(adr_BETRIEBSSTUNDEN_hh),temp
	; 10 DATEN auslesen BETRIEBSSTUNDEN-mm
	rcall EEPROM_READ_PLUS 					; INP: ZL+ZH(ADRESSE) OUT: TEMP (DATEN) (Z +1)	
	STS(adr_BETRIEBSSTUNDEN_mm),temp
	; 11 DATEN auslesen BETRIEBSSTUNDEN-ss
	rcall EEPROM_READ_PLUS 					; INP: ZL+ZH(ADRESSE) OUT: TEMP (DATEN) (Z +1)	
	STS(adr_BETRIEBSSTUNDEN_ss),temp

ret
;######################################################################## 
;######################################################################## 
;######################################################################## 
BETRIEBSSTUNDEN_SPEICHERN:
	; muss wert in EEPROM gespeichert werden ?
	LDS temp,(adr_BETRIEBSSTUNDEN_SPEICHERN); aus SRAM holen	
	cpi temp, (EEPROM_AUTO_SPEICHERN)
	brsh BETRIEBSSTUNDEN_SPEICHERN_w
	ret
BETRIEBSSTUNDEN_SPEICHERN_w:
	clr temp
	STS (adr_BETRIEBSSTUNDEN_SPEICHERN),temp; in SRAM speichern 

	rcall SYSTEM_EINSTELLUNGEN_EEPROM_SPEICHERN
ret
;######################################################################## 
;######################################################################## 
;######################################################################## 
BERECHNUNG_ONLINE_OFFLINE:
	LDS temp1,(adr_GPS_hh)				; aus SRAM holen	
	LDS temp2,(adr_GPS_mm)
	LDS temp3,(adr_GPS_ss)

	LDS temp,(adr_GPS_AKTIV)			; aus SRAM holen	
	tst temp
	brne BERECHNUNG_ONLINE_OFFLINE_ON
	STS (adr_GPS_ONLINE_hh),temp1		; in SRAM speichern	
	STS (adr_GPS_ONLINE_mm),temp2
	STS (adr_GPS_ONLINE_ss),temp3
	ret
BERECHNUNG_ONLINE_OFFLINE_ON:
	STS (adr_GPS_OFFLINE_hh),temp1		; in SRAM speichern	
	STS (adr_GPS_OFFLINE_mm),temp2
	STS (adr_GPS_OFFLINE_ss),temp3
ret
;######################################################################## 
;######################################################################## 
;######################################################################## 
ANZEIGE_LED_ROT:
	LDS temp,(adr_GPS_AKTIV)				; aus SRAM holen	
	tst temp
	breq ANZEIGE_LED_ROT_w
	rcall LED_ROT_OFF						; aus	
	ret
ANZEIGE_LED_ROT_w:
	rcall LED_ROT_ON						; an	
ret
;######################################################################## 
;######################################################################## 
;######################################################################## 
LED_ROT_ON:
	; invertierte Darstellung ?
	LDS temp,(adr_LED_ROT_INVERTIEREN) ; aus SRAM laden		
	tst temp
	brne LED_ROT_OFF_w		; aus	

LED_ROT_ON_w:
	cbi PORTD, LED_D_ROT	; ROT an	
ret
;######################################################################## 
;######################################################################## 
;######################################################################## 
LED_ROT_OFF:
	; invertierte Darstellung ?
	LDS temp,(adr_LED_ROT_INVERTIEREN) ; aus SRAM laden		
	tst temp
	brne LED_ROT_ON_w

LED_ROT_OFF_w:
	sbi PORTD, LED_D_ROT	; ROT aus	
ret
;###################################################################
;###################################################################
;###################################################################
; 																	
; Betriebsspannung													
; 																	
MESSEN_0:

	in temp, ADMUX
	andi temp, 0b11100000
	subi temp, 0			; KANAL 0	
	out ADMUX, temp

	rcall MESSEN			; OUT: TEMP1 / TEMP2	

	; mal REFERENZ-SPANNUNG	
	ldi temp3, LOW (SPANNUNG_REFERENZ)
	ldi temp4, HIGH(SPANNUNG_REFERENZ)
	rcall FUNKTION_MULTIPLIKATION_16_16	; INP: TEMP1+2/TEMP3+4	OUT: Temp1...4		
	; durch 256				
	mov temp1, temp2
	mov temp2, temp3
	clr temp3
	; durch 4				
	LSR temp2
	ROR temp1
	LSR temp2
	ROR temp1
	; mal WIDERSTANDSWERT (R_1 + R_2)
	ldi temp3, LOW (R_1 + R_2)
	ldi temp4, HIGH(R_1 + R_2)
	rcall FUNKTION_MULTIPLIKATION_16_16	; INP: TEMP1+2/TEMP3+4	OUT: Temp1...4		
	; durch Widerstandswert (R_2)
	ldi temp5, LOW (R_2)
	ldi temp6, HIGH(R_2)
	clr temp7
	clr temp8
 	rcall DIVISION_32_32	; INP: Temp1...Temp4 / Temp5...Temp8 OUT: Temp1...Temp4	
	STS adr_SPANNUNG_L,temp1	; in SRAM speichern
	STS adr_SPANNUNG_H,temp2	; in SRAM speichern

ret
;###################################################################
;###################################################################
;###################################################################
; 																	
; TEMPERATUR LM35 CZ 0,1V= 10C										
; 																	
MESSEN_1:
	in temp, ADMUX
	andi temp, 0b11100000
	subi temp, -1			; KANAL 1	
	out ADMUX, temp

	rcall MESSEN			; OUT: TEMP1 / TEMP2	
	; mal REFERENZ-SPANNUNG	
	ldi temp3, LOW (SPANNUNG_REFERENZ)
	ldi temp4, HIGH(SPANNUNG_REFERENZ)
	rcall FUNKTION_MULTIPLIKATION_16_16	; INP: TEMP1+2/TEMP3+4	OUT: Temp1...4		
	; durch 1024			
	mov temp1, temp2	; durch 256				
	mov temp2, temp3
	clr temp3
	LSR temp2			; durch 4				
	ROR temp1
	LSR temp2
	ROR temp1

	STS adr_TEMPERATUR_L,temp1	; in SRAM speichern
	STS adr_TEMPERATUR_H,temp2	; in SRAM speichern

ret
;###################################################################
;###################################################################
;###################################################################
; OUT: 	TEMP1 (low)  	
;		TEMP2			
; 						
MESSEN:

; SRAM WERTE lschen			
	clr temp
	STS adr_ADC_BYTE_1, temp 	; (low)
	STS adr_ADC_BYTE_2, temp 
	STS adr_ADC_BYTE_3, temp 
	clr temp7

; neuen ADC-Wert lesen	 Wert verwerfen, da meist vom vorherigem ADC-Kanal
MESSEN_w:
	sbi ADCSRA, ADIF    ; logisch "1" lscht ADIF flag !
MESSEN_ww:                  
	sbis ADCSRA, ADIF	; warten bis ADIF flag gesetzt
	rjmp MESSEN_ww

; neuen ADC-Wert lesen				
MESSEN_www:                
	sbi ADCSRA, ADIF    ; logisch "1" lscht ADIF flag !
MESSEN_wwww:                
	sbis ADCSR, ADIF 	; warten bis ADIF flag gesetzt
	rjmp MESSEN_wwww
; ADC einlesen:						
	in  temp1, ADCL 	; immer zuerst low byte lesen
	in  temp2, ADCH 	; danach das mittlerweile gesperrte high byte
	clr temp3
; Wert aus SRAM holen		
	LDS temp4, adr_ADC_BYTE_1 	; (low)
	LDS temp5, adr_ADC_BYTE_2
	LDS temp6, adr_ADC_BYTE_3
; Wert addieren				
	add temp4, temp1			; (low)
	adc temp5, temp2
	adc temp6, temp3
; WERT in SRAM schreiben	
	STS adr_ADC_BYTE_1, temp4 	; (low)
	STS adr_ADC_BYTE_2, temp5 
	STS adr_ADC_BYTE_3, temp6 

	dec temp7					; temp7 = 0			
	brne MESSEN_www				; nein=>Schleife 	
; Werte aus SRAM holen	und durch 256 teilen		
	LDS temp1, adr_ADC_BYTE_2 	; (low)
	LDS temp2, adr_ADC_BYTE_3



ret
;###################################################################
;###################################################################
;###################################################################
; INPUT:	ZL Adresse (low)										
;			ZH Adresse (High)										
;																	
; OUTPUT: 	TEMP (DATEN)											
;																	
; rcall EEPROM_READ_PLUS ; INP: ZL+ZH(ADRESSE) OUT: TEMP (DATEN)	
;																	
EEPROM_READ_PLUS:
	sbic EECR,EEWE 		; Wait for completion of previous write
	rjmp EEPROM_READ_PLUS
	out  EEARH, ZH		; ADRESSE setzen						
	out  EEARL, ZL
	sbi  EECR,EERE		; Start eeprom read by writing EERE		
	in 	 temp,EEDR		; Read data from data register			
	adiw ZL,1			; ADRESSE +1 							
ret
;###################################################################
;###################################################################
;###################################################################
; INPUT:	ZL Adresse (low)										
;			ZH Adresse (High)										
;																	
; 		 	TEMP  DATEN												
;																	
;	rcall EEPROM_WRITE_PLUS	; INP: TEMP(DATEN) ZL+ZH(ADRESSE) (Z+1)	
;																	
EEPROM_WRITE_PLUS:
	sbic EECR,EEWE		; Wait for completion of previous write
	rjmp EEPROM_WRITE_PLUS
	out  EEARH,ZH		; ADRESSE setzen						
	out  EEARL,ZL
	out  EEDR, temp		; Write data  to data register			
	sbi  EECR, EEMWE	; Write logical one to EEMWE			
	sbi  EECR, EEWE		; Start eeprom write by setting EEWE	
	adiw ZL,1			; ADRESSE +1 							
ret
;#######################################################################
;#######################################################################
;#######################################################################
;																		
; 	INPUT: temp1														
;																		
;	rcall SENDEN 		; INP: temp1									
;																		
SENDEN:
	sbis UCSRA,UDRE     	; Warten bis UDR frei             	
	rjmp senden				; Sprung							
	out UDR, temp1			; senden							
ret
;######################################################################## 
;######################################################################## 
;######################################################################## 

.include "GPS_LCD.asm" 
.include "GPS_FUNKTIONEN.asm" 
.include "GPS_INTERRUPT.asm" 

;######################################################################## 
;######################################################################## 
;######################################################################## 
TEXT_BEGRUESSUNG1:
.db "ATmega8",0

TEXT_BEGRUESSUNG3:
.db "MAI 2006 ",0

TEXT_BEGRUESSUNG4:
.db "GPS",0

TEXT_ERROR:
.db "ERROR !!!",0

TEXT_RESET:
.db "RESET",0

TEXT_WAIT:
.db "wait...",0

TEXT_AKTUELL:
.db "aktuell",0

TEXT_HOEHE:
.db "HOEHE",0

TEXT_HOEHE_OFFSET_NULL:
.db "HOEHE-OFFSET=0",0

TEXT_HOEHE_OFFSET_GPS:
.db "HOEHE-OFFSET=GPS",0

TEXT_HOEHE_OFFSET_REF:
.db "HOEHE-OFFSET=REF",0


TEXT_GPS:
.db "GPS",0

TEXT_BERECHNET:
.db "BERECHNET",0

TEXT_TEMPERATUR:
.db "Temperatur",0

TEXT_PROGRAMMSTARTS:
.db "PROGRAMM-STARTS",0

TEXT_SPANNUNG:
.db "SPANNUNG",0

TEXT_FEHLER_CODE:
.db "FEHLER-CODE",0

TEXT_MCUCSR:
.db "MCUCSR",0

TEXT_SATELLITEN:
.db "SATTELLITEN",0

TEXT_AKTIVE_REFERENZ:
.db "aktive Referenz",0

TEXT_REF_POSITIONEN:
.db "REF-POSITIONEN",0

TEXT_GESPEICHERT:
.db "gespeichert",0

TEXT_REFERENZ:
.db "REFERENZ",0

TEXT_DEZIMAL:
.db "dezimal",0

TEXT_GRD_MIN:
.db "GRD-MIN",0

TEXT_UTC_ZEIT:
.db "UTC-ZEIT",0

TEXT_BETRIEBSSTUNDEN:
.db "BETRIEBSSTUNDEN",0

TEXT_LED_ON:
.db "LED-ALLE-ON",0

TEXT_LED_OFF:
.db "LED-ALLE-OFF",0

TEXT_LED_LCD_OFF:
.db "LED-LCD-OFF",0

TEXT_LED_ROT_OFF:
.db "LED-ROT-OFF",0

TEXT_LED_BLAU_OFF:
.db "LED-BLAU-OFF",0

TEXT_LED_ROT_INVERTIEREN:
.db "ROT-INVERTIEREN",0

TEXT_TASTE_PLUS:
.db "TASTE+ druecken",0

TEXT_LADEN:
.db "LADEN",0

TEXT_SPEICHERN:
.db "SPEICHERN",0

TEXT_VIEW:
.db "VIEW",0

TEXT_EDIT:
.db "EDIT",0



TEXT_SRAM_EEPROM:
.db "SRAM-EEPROM",0

TEXT_NEUE_REFERENZ:
.db "neue REFERENZ !!",0 

TEXT_REFERENZ_A:
.db "EE-REFERENZ-A",0

TEXT_REFERENZ_B:
.db "EE-REFERENZ-B",0

TEXT_REFERENZ_C:
.db "EE-REFERENZ-C",0
; ------------------------------------







TEXT_REFERENZ_1:
.db "ZUHAUSE",0
DATEN_REFERENZ_1:
.dd 11020825,50987543,250 	; ZUHAUSE	(GRD-MIN-SEC: 5059,2526  1101,2495) 

TEXT_REFERENZ_2:
.db "MUHLBERG",0
DATEN_REFERENZ_2:
.dd 10816423,50869762,350 	; MHLBERG	(GRD-MIN-SEC: 5052,1857	1048,9854)

TEXT_REFERENZ_3:
.db "CARMEN",0
DATEN_REFERENZ_3:
.dd 11084960,50944010,360 	; CARMEN		

TEXT_REFERENZ_4:
.db "GOTHA",0
DATEN_REFERENZ_4:
.dd 10685150,50937310,0 	; GOTHA			

TEXT_REFERENZ_5:
.db "GROSSBREMBACH",0
DATEN_REFERENZ_5:
.dd 11317530,51111920,0 	; GROSSBREMBACH	

TEXT_REFERENZ_6:
.db "SCHWARZBURG",0
DATEN_REFERENZ_6:
.dd 11196430,50640950,0 	; SCHWARZBURG	

TEXT_REFERENZ_7:
.db "ERFURT-BRUECKE",0
DATEN_REFERENZ_7:
.dd 11088641,50913755,478 	; AUTOBAHN-BRCKE ERFURT

TEXT_REFERENZ_8:
.db "ROSTOCK",0
DATEN_REFERENZ_8:
.dd 12086520,54186740,0 	; ROSTOCK	

TEXT_REFERENZ_9:
.db "KRASSOW",0
DATEN_REFERENZ_9:
.dd 11573310,53876540,0 	; KRASSOW 	

TEXT_REFERENZ_10:
.db "HAMBURG",0
DATEN_REFERENZ_10:
.dd  9966530,53545110,0 	; HAMBURG 	

TEXT_REFERENZ_11:
.db "INSELSBERG",0
DATEN_REFERENZ_11:
.dd 10461800,50849030,916 	; INSELSBERG